@@ -4,5 +4,5 @@ CFLAGS="-g" ./build.sh
 if [ ! -d .tup ]; then
 	./build/tup init
 fi
-./build/tup upd
+./build/tup
 echo "Build complete. If ./tup works, you can remove the 'build' directory."
