@@ -6,7 +6,8 @@ if [ $1 = "-m" ]; then
 	menu=$1
 	shift
 fi
-text=`./gen_text.sh $1`
+base=`basename $1`
+text=`./gen_text.sh $base`
 cat << HERE
 <html>
 <head>
@@ -30,7 +31,7 @@ cat $1
 cat << HERE
 <div style="clear:both;"></div>
 </div>
-<div id="footer">&copy; 2008-2021 Mike Shal. All Rights Reserved.</div>
+<div id="footer">&copy; 2008-2024 Mike Shal. All Rights Reserved.</div>
 HERE
 
 cat << HERE
