@@ -2,7 +2,7 @@
  *
  * tup - A file-based build system
  *
- * Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+ * Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -26,9 +26,9 @@
 #include "string_tree.h"
 #include "db_types.h"
 #include "bsd/queue.h"
+#include "tup_pcre.h"
 #include <stdio.h>
 #include <time.h>
-#include <pcre.h>
 
 struct variant;
 struct estring;
@@ -39,7 +39,7 @@ struct tup_entry {
 	tupid_t dt;
 	struct tup_entry *parent;
 	enum TUP_NODE_TYPE type;
-	time_t mtime;
+	struct timespec mtime;
 	tupid_t srcid;
 	struct variant *variant;
 	struct string_tree name;
@@ -51,7 +51,7 @@ struct tup_entry {
 	_Atomic int refcount;
 
 	/* For exclusions */
-	pcre *re;
+	pcre2_code *re;
 
 	/* For command strings */
 	char *flags;
@@ -60,8 +60,6 @@ struct tup_entry {
 	int displaylen;
 };
 
-LIST_HEAD(tup_entry_head, tup_entry);
-
 int tup_entry_add(tupid_t tupid, struct tup_entry **dest);
 int tup_entry_find_name_in_dir(struct tup_entry *tent, const char *name, int len,
 			       struct tup_entry **dest);
@@ -69,10 +67,10 @@ int tup_entry_find_name_in_dir_dt(struct tup_entry *dtent, const char *name, int
 				  struct tup_entry **dest);
 int tup_entry_add_to_dir(struct tup_entry *dtent, tupid_t tupid, const char *name, int len,
 			 const char *display, int displaylen, const char *flags, int flagslen,
-			 enum TUP_NODE_TYPE type, time_t mtime, tupid_t srcid,
+			 enum TUP_NODE_TYPE type, struct timespec mtime, tupid_t srcid,
 			 struct tup_entry **dest);
 int tup_entry_add_all(tupid_t tupid, tupid_t dt, enum TUP_NODE_TYPE type,
-		      time_t mtime, tupid_t srcid, const char *name, const char *display, const char *flags,
+		      struct timespec mtime, tupid_t srcid, const char *name, const char *display, const char *flags,
 		      struct tup_entry **dest);
 int tup_entry_resolve_dirs(void);
 int tup_entry_change_name_dt(tupid_t tupid, const char *new_name, tupid_t dt);
@@ -93,13 +91,16 @@ void tup_entry_set_verbose(int verbose);
 void print_tup_entry(FILE *f, struct tup_entry *tent);
 void print_tupid(FILE *f, tupid_t tupid);
 int snprint_tup_entry(char *dest, int len, struct tup_entry *tent);
+int write_tup_entry(FILE *f, struct tup_entry *tent);
 int tup_entry_clear(void);
 int tup_entry_add_ghost_tree(struct tent_entries *root, struct tup_entry *tent);
 int tup_entry_debug_add_all_ghosts(struct tent_entries *root);
 int tup_entry_get_dir_tree(struct tup_entry *tent, struct tupid_entries *root);
 void dump_tup_entry(void);
 int get_relative_dir(FILE *f, struct estring *e, tupid_t start, tupid_t end);
+int get_relative_dir_sep(FILE *f, struct estring *e, tupid_t start, tupid_t end, char sep);
 int is_transient_tent(struct tup_entry *tent);
-int exclusion_match(FILE *f, struct tent_entries *exclusion_root, const char *s, int *match);
+int is_compiledb_tent(struct tup_entry *tent);
+int exclusion_match(FILE *f, struct tent_entries *exclusion_root, const char *s, struct tup_entry **match);
 
 #endif
