@@ -2,7 +2,7 @@
  *
  * tup - A file-based build system
  *
- * Copyright (C) 2008-2021  Mike Shal <marfey@gmail.com>
+ * Copyright (C) 2008-2024  Mike Shal <marfey@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -48,7 +48,7 @@ static int add_parser_files_locked(struct file_info *finfo,
 
 static _Thread_local struct mempool pool = MEMPOOL_INITIALIZER(struct file_entry);
 
-int init_file_info(struct file_info *info, const char *variant_dir, int do_unlink)
+int init_file_info(struct file_info *info, int do_unlink)
 {
 	TAILQ_INIT(&info->read_list);
 	TAILQ_INIT(&info->write_list);
@@ -64,14 +64,6 @@ int init_file_info(struct file_info *info, const char *variant_dir, int do_unlin
 	tent_tree_init(&info->exclusion_root);
 	pthread_mutex_init(&info->lock, NULL);
 	pthread_cond_init(&info->cond, NULL);
-	/* Root variant gets a NULL variant_dir so we can skip trying to do the
-	 * same thing twice in the server (eg: we only need a single readdir()
-	 * on the src tree).
-	 */
-	if(variant_dir[0])
-		info->variant_dir = variant_dir;
-	else
-		info->variant_dir = NULL;
 	info->server_fail = 0;
 	info->open_count = 0;
 	info->do_unlink = do_unlink;
@@ -143,6 +135,7 @@ static int add_symlinks(const char *path, struct file_info *finfo)
 	if(linkpath) {
 		if(handle_open_file(ACCESS_READ, linkpath, finfo) < 0) {
 			fprintf(stderr, "tup error: Failed to call handle_open_file on a symlink event '%s'\n", linkpath);
+			free(linkpath);
 			return -1;
 		}
 		free(linkpath);
@@ -250,7 +243,7 @@ int write_files(FILE *f, tupid_t cmdid, struct file_info *info, int *warnings,
 
 	if(check_only == CHECK_SUCCESS) {
 		while(!TAILQ_EMPTY(&info->tmpdir_list)) {
-			int match = 0;
+			struct tup_entry *match = NULL;
 
 			tmpdir = TAILQ_FIRST(&info->tmpdir_list);
 			if(exclusion_match(f, &info->exclusion_root, tmpdir->dirname, &match) < 0)
@@ -350,7 +343,7 @@ static int add_node_to_tree(tupid_t dt, const char *filename,
 	if(get_path_elements(filename, &pg) < 0)
 		return -1;
 
-	new_dt = find_dir_tupid_dt_pg(dt, &pg, &pel, 1, full_deps);
+	new_dt = find_dir_tupid_dt_pg(dt, &pg, &pel, SOTGV_CREATE_GHOSTS, full_deps);
 	if(new_dt < 0)
 		return -1;
 	if(new_dt == 0) {
@@ -368,7 +361,7 @@ static int add_node_to_tree(tupid_t dt, const char *filename,
 	if(tup_db_select_tent_part(new_dtent, pel->path, pel->len, &tent) < 0)
 		return -1;
 	if(!tent) {
-		time_t mtime = -1;
+		struct timespec mtime = INVALID_MTIME;
 		int type = TUP_NODE_GHOST;
 		if(full_deps && (pg.pg_flags & PG_OUTSIDE_TUP)) {
 			if(get_outside_tup_mtime(new_dtent, pel, &mtime) < 0)
@@ -386,7 +379,7 @@ static int add_node_to_tree(tupid_t dt, const char *filename,
 	free_pel(pel);
 	del_pel_group(&pg);
 
-	if(tent->type == TUP_NODE_DIR || tent->type == TUP_NODE_GENERATED_DIR || tent->mtime == 0) {
+	if(tent->type == TUP_NODE_DIR || tent->type == TUP_NODE_GENERATED_DIR || tent->mtime.tv_sec == 0) {
 		/* We don't track dependencies on directory nodes for commands. Note that
 		 * some directory accesses may create ghost nodes as placeholders for the
 		 * directory until a real directory is created there (eg: t5077). In this
@@ -405,13 +398,16 @@ static int add_node_to_tree(tupid_t dt, const char *filename,
 
 #ifdef _WIN32
 #include <windows.h>
+
 #define WINDOWS_TICK 10000000
 #define SEC_TO_UNIX_EPOCH 11644473600LL
 
-static unsigned filetime_to_epoch(FILETIME *ft)
+static struct timespec ticks_to_timespec(long long ticks)
 {
-        long long ticks = (((long long)ft->dwHighDateTime) << 32) + (long long)ft->dwLowDateTime;
-        return (unsigned)(ticks / WINDOWS_TICK - SEC_TO_UNIX_EPOCH);
+	struct timespec ts;
+	ts.tv_sec = ticks / WINDOWS_TICK - SEC_TO_UNIX_EPOCH;
+	ts.tv_nsec = ticks % WINDOWS_TICK * 100;
+	return ts;
 }
 
 static int file_set_mtime(struct tup_entry *tent, const char *file)
@@ -431,26 +427,6 @@ static int file_set_mtime(struct tup_entry *tent, const char *file)
 	wcscpy(widefile, L"\\\\?\\");
 	dest += prefix_len;
 	pos += prefix_len;
-	if(!is_full_path(file)) {
-		/* !tup_ln links give us ACCESS_WRITE files with tup-top
-		 * relative paths, so we need to prefix with the working
-		 * directory or else GetFileAttributesExW below can fail since
-		 * we don't have the dir_mutex.
-		 */
-		if(file[0] != '.' && file[1] != '/') {
-			fprintf(stderr, "tup internal error: Expected relative path to start with ./ in file_set_mtime(): %s\n", file);
-			return -1;
-		}
-		MultiByteToWideChar(CP_UTF8, 0, get_tup_top(), -1, dest, WIDE_PATH_MAX - pos);
-		dest += get_tup_top_len();
-		pos += get_tup_top_len();
-		if(pos >= WIDE_PATH_MAX) {
-			fprintf(stderr, "tup error: WIDE_PATH_MAX is too small in file_set_mtime()\n");
-			return -1;
-		}
-		/* Skip the '.' part of the path */
-		file++;
-	}
 	MultiByteToWideChar(CP_UTF8, 0, file, -1, dest, WIDE_PATH_MAX - pos);
 	widefile[WIDE_PATH_MAX-1] = 0;
 	/* Backout the forward-slash conversion used for regex matching. */
@@ -463,10 +439,16 @@ static int file_set_mtime(struct tup_entry *tent, const char *file)
 		fprintf(stderr, "tup error: GetFileAttributesExW(\"%ls\") failed: 0x%08lx\n", widefile, GetLastError());
 		return -1;
 	}
-	if(tup_db_set_mtime(tent, filetime_to_epoch(&data.ftLastWriteTime)) < 0)
+	if(tup_db_set_mtime(tent, ticks_to_timespec(FILETIME_TO_TICKS(&data.ftLastWriteTime))) < 0)
 		return -1;
 	return 0;
 }
+
+struct timespec win_mtime(struct stat *buf)
+{
+	return ticks_to_timespec(buf->st_mtime);
+}
+
 #else
 static int file_set_mtime(struct tup_entry *tent, const char *file)
 {
@@ -665,9 +647,17 @@ static int create_ignored_file(FILE *f, struct file_entry *w)
 	struct path_element *pel = NULL;
 	struct tup_entry *tent;
 	struct tup_entry *dtent;
+	struct pel_group pg;
+	int type = TUP_NODE_FILE;
 	tupid_t dt;
 
-	dt = find_dir_tupid_dt(DOT_DT, w->filename, &pel, SOTGV_IGNORE_DIRS, 1);
+	if(get_path_elements(w->filename, &pg) < 0)
+		return -1;
+	if(pg.pg_flags & PG_OUTSIDE_TUP) {
+		type = TUP_NODE_GHOST;
+	}
+
+	dt = find_dir_tupid_dt_pg(DOT_DT, &pg, &pel, SOTGV_IGNORE_DIRS, 1);
 	if(dt < 0) {
 		fprintf(f, "tup error: Unable to create directory tree for ignored file: %s\n", w->filename);
 		return -1;
@@ -676,11 +666,26 @@ static int create_ignored_file(FILE *f, struct file_entry *w)
 		fprintf(f, "tup internal error: create_ignored_file() didn't get a final pel pointer for file: %s\n", w->filename);
 		return -1;
 	}
-	if(tup_entry_add(dt, &dtent) < 0)
+	if(tup_entry_add(dt, &dtent) < 0) {
+		fprintf(f, "tup internal error: Unable to add entry for tupid %lli\n", dt);
 		return -1;
-	tent = tup_db_create_node_part(dtent, pel->path, pel->len, TUP_NODE_FILE, -1, NULL);
-	if(!tent)
+	}
+	if(tup_db_select_tent_part(dtent, pel->path, pel->len, &tent) < 0) {
 		return -1;
+	}
+	if(tent && tent->type == TUP_NODE_GENERATED) {
+		fprintf(f, "tup error: Unable to exclude a generated file: ");
+		print_tup_entry(f, tent);
+		fprintf(f, "\n");
+		return -1;
+	}
+	tent = tup_db_create_node_part(dtent, pel->path, pel->len, type, -1, NULL);
+	if(!tent) {
+		fprintf(f, "tup internal error: Unable to create node for file '%.*s' relative to directory: ", pel->len, pel->path);
+		print_tup_entry(f, dtent);
+		fprintf(f, "\n");
+		return -1;
+	}
 	free_pel(pel);
 	return 0;
 }
@@ -699,25 +704,10 @@ static int update_write_info(FILE *f, tupid_t cmdid, struct file_info *info,
 		tupid_t newdt;
 		struct path_element *pel = NULL;
 		struct pel_group pg;
-		int match = 0;
+		struct tup_entry *match = NULL;
 
 		w = TAILQ_FIRST(&info->write_list);
 
-		if(exclusion_match(f, &info->exclusion_root, w->filename, &match) < 0)
-			return -1;
-		if(match) {
-			if(create_ignored_file(f, w) < 0)
-				return -1;
-			goto out_skip;
-		}
-
-		/* Remove duplicate write entries */
-		TAILQ_FOREACH_SAFE(r, &info->write_list, list, tmp) {
-			if(r != w && (name_cmp(w->filename, r->filename) == 0)) {
-				del_file_entry(&info->write_list, r);
-			}
-		}
-
 		if(get_path_elements(w->filename, &pg) < 0)
 			return -1;
 		if(pg.pg_flags & PG_HIDDEN) {
@@ -729,8 +719,27 @@ static int update_write_info(FILE *f, tupid_t cmdid, struct file_info *info,
 			goto out_skip;
 		}
 
+		if(exclusion_match(f, &info->exclusion_root, w->filename, &match) < 0)
+			return -1;
+		if(match) {
+			if(create_ignored_file(f, w) < 0) {
+				fprintf(f, "tup error: Failed to create ignored file. The filename '%s' matched an exclusion pattern: ", w->filename);
+				print_tup_entry(f, match);
+				fprintf(f, "\n");
+				return -1;
+			}
+			goto out_skip;
+		}
+
+		/* Remove duplicate write entries */
+		TAILQ_FOREACH_SAFE(r, &info->write_list, list, tmp) {
+			if(r != w && (name_cmp(w->filename, r->filename) == 0)) {
+				del_file_entry(&info->write_list, r);
+			}
+		}
+
 		tent = NULL;
-		newdt = find_dir_tupid_dt_pg(DOT_DT, &pg, &pel, 0, 0);
+		newdt = find_dir_tupid_dt_pg(DOT_DT, &pg, &pel, SOTGV_NO_GHOST, 0);
 		del_pel_group(&pg);
 		if(newdt > 0) {
 			struct tup_entry *dtent;
@@ -838,7 +847,7 @@ static int update_read_info(FILE *f, tupid_t cmdid, struct file_info *info,
 	struct tent_entries root = TENT_ENTRIES_INITIALIZER;
 
 	while(!TAILQ_EMPTY(&info->read_list)) {
-		int match = 0;
+		struct tup_entry *match = NULL;
 		r = TAILQ_FIRST(&info->read_list);
 
 		if(exclusion_match(f, &info->exclusion_root, r->filename, &match) < 0)
