@@ -2,7 +2,7 @@
  *
  * tup - A file-based build system
  *
- * Copyright (C) 2015-2021  Mike Shal <marfey@gmail.com>
+ * Copyright (C) 2015-2024  Mike Shal <marfey@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -226,7 +226,7 @@ static int run_subprocess(int ofd, int dfd, const char *cmd, const char *depfile
 		if(dup2(null_fd, STDIN_FILENO) < 0) {
 			perror("dup2");
 			fprintf(stderr, "tup error: Unable to dup stdin for child processes.\n");
-			return -1;
+			exit(1);
 		}
 
 		if(fchdir(dfd) < 0) {
@@ -269,15 +269,13 @@ static void server_unlock(struct server *s)
 }
 
 int server_exec(struct server *s, int dfd, const char *cmd, struct tup_env *newenv,
-		struct tup_entry *dtent, int need_namespacing, int run_in_bash)
+		struct tup_entry *dtent)
 {
 	int fd;
 	char depfile[PATH_MAX];
-	char buf[64];
 	int status;
 
 	if(dtent) {}
-	if(need_namespacing) {}
 
 	snprintf(depfile, PATH_MAX, "%s/%s/deps-%i", get_tup_top(), TUP_TMP, s->id);
 	depfile[PATH_MAX-1] = 0;
@@ -287,13 +285,20 @@ int server_exec(struct server *s, int dfd, const char *cmd, struct tup_env *newe
 		fprintf(stderr, "tup error: Unable to create dependency file for the sub-process.\n");
 		return -1;
 	}
-	snprintf(buf, sizeof(buf), ".tup/tmp/output-%i", s->id);
-	s->output_fd = open(buf, O_CREAT | O_RDWR | O_CLOEXEC | O_TRUNC, 0600);
-	if(s->output_fd < 0) {
-		perror(buf);
-		return -1;
+	int output_fd;
+	if(!s->streaming_mode) {
+		char buf[64];
+		snprintf(buf, sizeof(buf), ".tup/tmp/output-%i", s->id);
+		s->output_fd = open(buf, O_CREAT | O_RDWR | O_CLOEXEC | O_TRUNC, 0600);
+		if(s->output_fd < 0) {
+			perror(buf);
+			return -1;
+		}
+		output_fd = s->output_fd;
+	} else {
+		output_fd = STDOUT_FILENO;
 	}
-	if(run_subprocess(s->output_fd, dfd, cmd, depfile, newenv, run_in_bash, &status) < 0) {
+	if(run_subprocess(output_fd, dfd, cmd, depfile, newenv, s->run_in_bash, &status) < 0) {
 		close(fd);
 		return -1;
 	}
@@ -326,15 +331,17 @@ int server_exec(struct server *s, int dfd, const char *cmd, struct tup_env *newe
 
 int server_postexec(struct server *s)
 {
-	char buf[64];
-	snprintf(buf, sizeof(buf), ".tup/tmp/output-%i", s->id);
-	buf[sizeof(buf)-1] = 0;
-	if(unlinkat(tup_top_fd(), buf, 0) < 0) {
-		server_lock(s);
-		perror(buf);
-		fprintf(stderr, "tup error: Unable to unlink sub-process output file.\n");
-		server_unlock(s);
-		return -1;
+	if(!s->streaming_mode) {
+		char buf[64];
+		snprintf(buf, sizeof(buf), ".tup/tmp/output-%i", s->id);
+		buf[sizeof(buf)-1] = 0;
+		if(unlinkat(tup_top_fd(), buf, 0) < 0) {
+			server_lock(s);
+			perror(buf);
+			fprintf(stderr, "tup error: Unable to unlink sub-process output file.\n");
+			server_unlock(s);
+			return -1;
+		}
 	}
 	return 0;
 }
@@ -380,17 +387,6 @@ int serverless_run_script(FILE *f, const char *cmdline,
 	return -1;
 }
 
-int server_symlink(struct server *s, const char *target, int dfd, const char *linkpath)
-{
-	if(s) {/* unused */}
-	if(symlinkat(target, dfd, linkpath) < 0) {
-		perror("symlinkat");
-		fprintf(stderr, "tup error: unable to create symlink at '%s' pointing to target '%s'\n", linkpath, target);
-		return -1;
-	}
-	return 0;
-}
-
 static int process_depfile(struct server *s, int fd)
 {
 	char event1[PATH_MAX];
