@@ -2,7 +2,7 @@
  *
  * tup - A file-based build system
  *
- * Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+ * Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -38,6 +38,7 @@
 #include <string.h>
 #include <dirent.h>
 #include <errno.h>
+#include <libgen.h>
 #include <sys/types.h>
 #include <sys/resource.h>
 
@@ -161,27 +162,6 @@ static const char *peel(const char *path)
 	return path;
 }
 
-static const char *prefix_strip(const char *peeled, const char *variant_dir)
-{
-	if(strncmp(peeled, get_tup_top(), get_tup_top_len()) == 0) {
-		int variant_len = strlen(variant_dir);
-
-		peeled += get_tup_top_len();
-
-		/* Now we need to match the variant directory. Note these
-		 * always begin with a '/'.
-		 */
-		if(strncmp(peeled, variant_dir, variant_len) != 0)
-			return NULL;
-		peeled += variant_len;
-		if(peeled[0] != '/')
-			return NULL;
-		peeled++;
-		return peeled;
-	}
-	return NULL;
-}
-
 static struct mapping *add_mapping_internal(struct file_info *finfo, const char *path)
 {
 	static int filenum = 0;
@@ -336,22 +316,18 @@ static void tup_fuse_handle_file(const char *path, const char *stripped, enum ac
 	}
 }
 
-static const char *get_virtual_var(const char *peeled, const char *variant_dir)
+static const char *get_virtual_var(const char *peeled)
 {
 	const char *stripped;
 
-	if(variant_dir) {
-		stripped = prefix_strip(peeled, variant_dir);
-	} else {
-		if(strncmp(peeled, get_tup_top(), get_tup_top_len()) == 0) {
-			peeled += get_tup_top_len();
-			if(peeled[0] != '/')
-				return NULL;
-			peeled++;
-			stripped = peeled;
-		} else {
+	if(strncmp(peeled, get_tup_top(), get_tup_top_len()) == 0) {
+		peeled += get_tup_top_len();
+		if(peeled[0] != '/')
 			return NULL;
-		}
+		peeled++;
+		stripped = peeled;
+	} else {
+		return NULL;
 	}
 	if(stripped) {
 		const char *var = strstr(stripped, TUP_VAR_VIRTUAL_DIR);
@@ -376,7 +352,6 @@ static int tup_fs_getattr(const char *path, struct stat *stbuf)
 	struct tmpdir *tmpdir;
 	struct file_info *finfo;
 	const char *var;
-	const char *variant_dir = NULL;
 	const char *stripped = NULL;
 	int rc;
 
@@ -414,8 +389,6 @@ static int tup_fs_getattr(const char *path, struct stat *stbuf)
 		map = find_mapping(finfo, path);
 		if(map)
 			peeled = map->tmpname;
-		else
-			variant_dir = finfo->variant_dir;
 		put_finfo(finfo);
 	}
 
@@ -425,7 +398,7 @@ static int tup_fs_getattr(const char *path, struct stat *stbuf)
 	 * track of the variable and return failure because we're not actually
 	 * going to open anything.
 	 */
-	var = get_virtual_var(peeled, variant_dir);
+	var = get_virtual_var(peeled);
 	if(var) {
 		if(var[0] == 0) {
 			stbuf->st_mode = S_IFDIR | 0755;
@@ -451,13 +424,6 @@ static int tup_fs_getattr(const char *path, struct stat *stbuf)
 	}
 
 	res = fstatat(tup_top_fd(), peeled, stbuf, AT_SYMLINK_NOFOLLOW);
-	if (res == -1 && variant_dir) {
-		stripped = prefix_strip(peeled, variant_dir);
-		if(stripped) {
-			res = fstatat(tup_top_fd(), stripped, stbuf, AT_SYMLINK_NOFOLLOW);
-		}
-	}
-
 	if (res == -1) {
 		rc = -errno;
 	} else {
@@ -476,7 +442,6 @@ static int tup_fs_access(const char *path, int mask)
 	struct file_info *finfo;
 	struct tmpdir *tmpdir;
 	const char *var;
-	const char *variant_dir = NULL;
 
 	if(context_check() < 0)
 		return -EPERM;
@@ -491,9 +456,6 @@ static int tup_fs_access(const char *path, int mask)
 		map = find_mapping(finfo, path);
 		if(map)
 			peeled = map->tmpname;
-		else
-			variant_dir = finfo->variant_dir;
-
 
 		TAILQ_FOREACH(tmpdir, &finfo->tmpdir_list, list) {
 			if(strcmp(tmpdir->dirname, peeled) == 0) {
@@ -519,19 +481,13 @@ static int tup_fs_access(const char *path, int mask)
 	 * var[0] == 0 check means it is just the @tup@ directory itself, and
 	 * not a variable name.
 	 */
-	var = get_virtual_var(peeled, variant_dir);
+	var = get_virtual_var(peeled);
 	if(var && var[0] == 0) {
 		return 0;
 	}
 
 	/* This is preceded by a getattr - no need to handle a read event */
 	res = faccessat(tup_top_fd(), peeled, mask, 0);
-	if (res == -1 && variant_dir) {
-		const char *stripped = prefix_strip(peeled, variant_dir);
-		if(stripped) {
-			res = faccessat(tup_top_fd(), stripped, mask, 0);
-		}
-	}
 	if (res == -1)
 		return -errno;
 
@@ -544,7 +500,6 @@ static int tup_fs_readlink(const char *path, char *buf, size_t size)
 	const char *peeled;
 	struct file_info *finfo;
 	struct mapping *map;
-	const char *variant_dir = NULL;
 	const char *stripped = NULL;
 
 	if(context_check() < 0)
@@ -554,7 +509,6 @@ static int tup_fs_readlink(const char *path, char *buf, size_t size)
 
 	finfo = get_finfo(path);
 	if(finfo) {
-		variant_dir = finfo->variant_dir;
 		map = find_mapping(finfo, path);
 		if(map)
 			peeled = map->tmpname;
@@ -575,12 +529,6 @@ static int tup_fs_readlink(const char *path, char *buf, size_t size)
 		}
 	} else {
 		res = readlinkat(tup_top_fd(), peeled, buf, size - 1);
-		if(res == -1 && variant_dir) {
-			stripped = prefix_strip(peeled, variant_dir);
-			if(stripped) {
-				res = readlinkat(tup_top_fd(), stripped, buf, size - 1);
-			}
-		}
 		if(res == -1)
 			return -errno;
 	}
@@ -607,7 +555,7 @@ static void add_dir_entries(DIR *dp, void *buf, fuse_fill_dir_t filler,
 }
 
 static int fill_actual_directory(const char *peeled, void *buf,
-				 fuse_fill_dir_t filler, int ignore_dot_tup, const char *variant_dir)
+				 fuse_fill_dir_t filler, int ignore_dot_tup)
 {
 	DIR *dp;
 	int fd;
@@ -621,24 +569,10 @@ static int fill_actual_directory(const char *peeled, void *buf,
 		add_dir_entries(dp, buf, filler, ignore_dot_tup);
 		closedir(dp);
 	}
-
-	if(variant_dir)  {
-		const char *stripped = prefix_strip(peeled, variant_dir);
-		if(stripped) {
-			fd = openat(tup_top_fd(), stripped, O_RDONLY);
-			if(fd >= 0) {
-				dp = fdopendir(fd);
-				if(dp == NULL)
-					return -errno;
-				add_dir_entries(dp, buf, filler, ignore_dot_tup);
-				closedir(dp);
-			}
-		}
-	}
 	return 0;
 }
 
-static int readdir_parser(const char *path, void *buf, fuse_fill_dir_t filler, const char *variant_dir)
+static int readdir_parser(const char *path, void *buf, fuse_fill_dir_t filler)
 {
 	if(strncmp(path, get_tup_top(), get_tup_top_len()) == 0) {
 		if(tup_fuse_server_get_dir_entries(path + get_tup_top_len(),
@@ -646,7 +580,7 @@ static int readdir_parser(const char *path, void *buf, fuse_fill_dir_t filler, c
 			return -EPERM;
 	} else {
 		/* t4052 */
-		return fill_actual_directory(path, buf, filler, 0, variant_dir);
+		return fill_actual_directory(path, buf, filler, 0);
 	}
 	return 0;
 }
@@ -661,8 +595,6 @@ static int tup_fs_readdir(const char *path, void *buf, fuse_fill_dir_t filler,
 {
 	const char *peeled;
 	struct file_info *finfo;
-	const char *variant_dir = NULL;
-	const char *stripped = NULL;
 	int is_tmpdir = 0;
 
 	(void) offset;
@@ -686,7 +618,7 @@ static int tup_fs_readdir(const char *path, void *buf, fuse_fill_dir_t filler,
 		 */
 		if(server_mode == SERVER_PARSER_MODE) {
 			int rc;
-			rc = readdir_parser(peeled, buf, filler, finfo->variant_dir);
+			rc = readdir_parser(peeled, buf, filler);
 			if(rc < 0) {
 				finfo->server_fail = 1;
 			}
@@ -776,8 +708,6 @@ static int tup_fs_readdir(const char *path, void *buf, fuse_fill_dir_t filler,
 			}
 		}
 
-		variant_dir = finfo->variant_dir;
-
 		put_finfo(finfo);
 	}
 
@@ -786,18 +716,10 @@ static int tup_fs_readdir(const char *path, void *buf, fuse_fill_dir_t filler,
 
 	tup_fuse_handle_file(path, NULL, ACCESS_READ);
 
-	if(variant_dir) {
-		stripped = prefix_strip(peeled, variant_dir);
-		if(stripped) {
-			if(fill_actual_directory(stripped, buf, filler, finfo != NULL, NULL) < 0)
-				return -1;
-		}
-	}
-
 	/* If finfo is NULL, we're outside of tup, so we don't need to ignore
 	 * any files called '.tup' in that case.
 	 */
-	return fill_actual_directory(peeled, buf, filler, finfo != NULL, NULL);
+	return fill_actual_directory(peeled, buf, filler, finfo != NULL);
 }
 
 static int mknod_internal(const char *path, mode_t mode, int flags, int close_fd)
@@ -808,6 +730,27 @@ static int mknod_internal(const char *path, mode_t mode, int flags, int close_fd
 	if(context_check() < 0)
 		return -EPERM;
 
+	/* t5119 - Make sure we could write to the actual underlying directory,
+	 * since that can affect program behavior. For example, inkscape uses
+	 * fontconfig, which tries to write .uuid files in /usr/. If we report
+	 * that the write succeeds, we'll have issues with unspecified outputs.
+	 */
+	char *dir;
+	char *dirtmp = strdup(path);
+	if(!dirtmp) {
+		return -ENOMEM;
+	}
+	dir = dirname(dirtmp);
+
+	/* Use tup_fs_access in case it's a directory we mkdir'd during program
+	 * execution.
+	 */
+	rc = tup_fs_access(dir, W_OK);
+	free(dirtmp);
+	if(rc < 0) {
+		return -errno;
+	}
+
 	/* On Linux this could just be 'mknod(path, mode, rdev)' but this
 	   is more portable */
 	if (S_ISREG(mode)) {
@@ -930,6 +873,18 @@ static int tup_fs_unlink(const char *path)
 		}
 		put_finfo(finfo);
 	}
+	if(strstr(path, ".fuse_hidden") != NULL) {
+		/* Similar to the rename check for .fuse_hidden, this shows up
+		 * in Arch sometimes.
+		 */
+		const char *peeled = peel(path);
+		int res;
+
+		res = unlink(peeled);
+		if(res < 0)
+			return -errno;
+		return 0;
+	}
 	fprintf(stderr, "tup error: Unable to unlink files not created during this job: %s\n", peel(path));
 	return -EPERM;
 }
@@ -1055,16 +1010,29 @@ static int tup_fs_rename(const char *from, const char *to)
 			return -ENOENT;
 		}
 
-		free(map->realname);
-		map->realname = strdup(peelto);
-		if(!map->realname) {
-			perror("strdup");
+		if(strstr(peelto, ".fuse_hidden") != NULL) {
+			/* If we're renaming to a .fuse_hidden file, treat it
+			 * as if the source was unlinked. This happens
+			 * sometimes in an Arch VM where a deleted file shows
+			 * up in FUSE as a rename to a .fuse_hidden file,
+			 * especially in t4017 for some reason.
+			 */
+			unlinkat(tup_top_fd(), map->tmpname, 0);
+			del_map(&finfo->mapping_list, map);
 			put_finfo(finfo);
-			return -ENOMEM;
-		}
+			tup_fuse_handle_file(from, NULL, ACCESS_UNLINK);
+		} else {
+			free(map->realname);
+			map->realname = strdup(peelto);
+			if(!map->realname) {
+				perror("strdup");
+				put_finfo(finfo);
+				return -ENOMEM;
+			}
 
-		handle_rename(peelfrom, peelto, finfo);
-		put_finfo(finfo);
+			handle_rename(peelfrom, peelto, finfo);
+			put_finfo(finfo);
+		}
 	}
 
 	return 0;
@@ -1167,7 +1135,7 @@ static int tup_fs_truncate(const char *path, off_t size)
 	struct mapping *map;
 	struct file_info *finfo;
 	const char *peeled;
-	int match = 0;
+	struct tup_entry *match = NULL;
 
 #ifdef FUSE3
 	(void) fi;
@@ -1222,7 +1190,7 @@ static int tup_fs_utimens(const char *path, const struct timespec ts[2])
 	const char *peeled;
 	struct mapping *map;
 	struct file_info *finfo;
-	int match = 0;
+	struct tup_entry *match = NULL;
 
 #ifdef FUSE3
 	(void) fi;
@@ -1274,7 +1242,7 @@ static int tup_fs_create(const char *path, mode_t mode, struct fuse_file_info *f
 	struct file_info *finfo;
 	rc = mknod_internal(path, mode, fi->flags, 0);
 	if(rc < 0)
-		return -errno;
+		return rc;
 	finfo = get_finfo(path);
 	if(finfo) {
 		if(finfo->open_count >= max_open_files) {
@@ -1298,7 +1266,6 @@ static int tup_fs_open(const char *path, struct fuse_file_info *fi)
 	const char *openfile;
 	struct mapping *map;
 	struct file_info *finfo;
-	const char *variant_dir = NULL;
 	const char *stripped = NULL;
 
 	if(context_check() < 0)
@@ -1316,7 +1283,7 @@ static int tup_fs_open(const char *path, struct fuse_file_info *fi)
 			openfile = map->tmpname;
 		} else {
 #ifdef FUSE3
-			int match = 0;
+			struct tup_entry *match = NULL;
 			if(exclusion_match(stderr, &finfo->exclusion_root, path, &match) < 0) {
 				put_finfo(finfo);
 				return -ENOSYS;
@@ -1324,24 +1291,11 @@ static int tup_fs_open(const char *path, struct fuse_file_info *fi)
 			if(at == ACCESS_WRITE && !is_hidden(path) && !match) {
 				map = add_mapping_internal(finfo, path);
 				openfile = map->tmpname;
-			} else {
-				/* Only try the base dir if it's not a mapped file */
-				variant_dir = finfo->variant_dir;
 			}
-#else
-			/* Only try the base dir if it's not a mapped file */
-			variant_dir = finfo->variant_dir;
 #endif
 		}
 
 		fd = openat(tup_top_fd(), openfile, fi->flags);
-		if(fd < 0 && variant_dir) {
-			stripped = prefix_strip(peeled, variant_dir);
-			if(stripped) {
-				fd = openat(tup_top_fd(), stripped, fi->flags);
-			}
-		}
-
 		if(fd < 0) {
 			res = -errno;
 		} else {
