@@ -2,7 +2,7 @@
  *
  * tup - A file-based build system
  *
- * Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+ * Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -120,6 +120,12 @@ static int os_unmount(void)
 static int os_unmount(void)
 {
 	if(unmount(TUP_MNT, MNT_FORCE) < 0) {
+		if(errno == EBUSY) {
+			fprintf(stderr, "tup warning: FUSE filesystem busy on unmount, trying again...\n");
+			usleep(500000);
+			if(unmount(TUP_MNT, MNT_FORCE) == 0)
+				return 0;
+		}
 		perror("unmount");
 		return -1;
 	}
@@ -456,11 +462,9 @@ static int finfo_wait_open_count(struct server *s)
 }
 
 static int exec_internal(struct server *s, const char *cmd, struct tup_env *newenv,
-			 struct tup_entry *dtent, int single_output, int need_namespacing,
-			 int run_in_bash)
+			 struct tup_entry *dtent, int single_output)
 {
 	int status;
-	char buf[64];
 	char job[JOB_MAX];
 	char dir[PATH_MAX];
 	struct execmsg em;
@@ -469,8 +473,9 @@ static int exec_internal(struct server *s, const char *cmd, struct tup_env *newe
 	memset(&em, 0, sizeof(em));
 	em.sid = s->id;
 	em.single_output = single_output;
-	em.need_namespacing = need_namespacing;
-	em.run_in_bash = run_in_bash;
+	em.need_namespacing = s->need_namespacing;
+	em.run_in_bash = s->run_in_bash;
+	em.streaming_mode = s->streaming_mode;
 	em.envlen = newenv->block_size;
 	em.num_env_entries = newenv->num_entries;
 	em.joblen = snprintf(job, sizeof(job), TUP_MNT "/" TUP_JOB "%i", s->id) + 1;
@@ -482,7 +487,7 @@ static int exec_internal(struct server *s, const char *cmd, struct tup_env *newe
 	em.dirlen = get_tup_top_len() - 1;
 	em.dirlen += snprint_tup_entry(dir + em.dirlen,
 				       sizeof(dir) - em.dirlen - 1,
-				       dtent) + 1;
+				       variant_tent_to_srctent(dtent)) + 1;
 	if(em.joblen >= JOB_MAX || em.dirlen >= PATH_MAX) {
 		server_lock(s);
 		fprintf(stderr, "tup error: Directory for tup entry %lli is too long.\n", dtent->tnode.tupid);
@@ -503,42 +508,45 @@ static int exec_internal(struct server *s, const char *cmd, struct tup_env *newe
 	if(finfo_wait_open_count(s) < 0)
 		return -1;
 
-	snprintf(buf, sizeof(buf), ".tup/tmp/output-%i", s->id);
-	buf[sizeof(buf)-1] = 0;
-	s->output_fd = openat(tup_top_fd(), buf, O_RDONLY);
-	if(s->output_fd < 0) {
-		server_lock(s);
-		perror(buf);
-		fprintf(stderr, "tup error: Unable to open sub-process output file.\n");
-		server_unlock(s);
-		return -1;
-	}
-	if(unlinkat(tup_top_fd(), buf, 0) < 0) {
-		server_lock(s);
-		perror(buf);
-		fprintf(stderr, "tup error: Unable to unlink sub-process output file.\n");
-		server_unlock(s);
-		return -1;
-	}
-
-	if(!single_output) {
-		snprintf(buf, sizeof(buf), ".tup/tmp/errors-%i", s->id);
+	if(!s->streaming_mode) {
+		char buf[64];
+		snprintf(buf, sizeof(buf), ".tup/tmp/output-%i", s->id);
 		buf[sizeof(buf)-1] = 0;
-		s->error_fd = openat(tup_top_fd(), buf, O_RDWR);
-		if(s->error_fd < 0) {
+		s->output_fd = openat(tup_top_fd(), buf, O_RDONLY);
+		if(s->output_fd < 0) {
 			server_lock(s);
 			perror(buf);
-			fprintf(stderr, "tup error: Unable to open sub-process errors file.\n");
+			fprintf(stderr, "tup error: Unable to open sub-process output file.\n");
 			server_unlock(s);
 			return -1;
 		}
 		if(unlinkat(tup_top_fd(), buf, 0) < 0) {
 			server_lock(s);
 			perror(buf);
-			fprintf(stderr, "tup error: Unable to unlink sub-process errors file.\n");
+			fprintf(stderr, "tup error: Unable to unlink sub-process output file.\n");
 			server_unlock(s);
 			return -1;
 		}
+
+		if(!single_output) {
+			snprintf(buf, sizeof(buf), ".tup/tmp/errors-%i", s->id);
+			buf[sizeof(buf)-1] = 0;
+			s->error_fd = openat(tup_top_fd(), buf, O_RDWR);
+			if(s->error_fd < 0) {
+				server_lock(s);
+				perror(buf);
+				fprintf(stderr, "tup error: Unable to open sub-process errors file.\n");
+				server_unlock(s);
+				return -1;
+			}
+			if(unlinkat(tup_top_fd(), buf, 0) < 0) {
+				server_lock(s);
+				perror(buf);
+				fprintf(stderr, "tup error: Unable to unlink sub-process errors file.\n");
+				server_unlock(s);
+				return -1;
+			}
+		}
 	}
 
 	if(WIFEXITED(status)) {
@@ -557,7 +565,7 @@ static int exec_internal(struct server *s, const char *cmd, struct tup_env *newe
 }
 
 int server_exec(struct server *s, int dfd, const char *cmd, struct tup_env *newenv,
-		struct tup_entry *dtent, int need_namespacing, int run_in_bash)
+		struct tup_entry *dtent)
 {
 	int rc;
 
@@ -566,7 +574,7 @@ int server_exec(struct server *s, int dfd, const char *cmd, struct tup_env *newe
 	if(tup_fuse_add_group(s->id, &s->finfo) < 0)
 		return -1;
 
-	rc = exec_internal(s, cmd, newenv, dtent, 1, need_namespacing, run_in_bash);
+	rc = exec_internal(s, cmd, newenv, dtent, 1);
 
 	if(tup_fuse_rm_group(&s->finfo) < 0)
 		return -1;
@@ -604,10 +612,13 @@ int server_run_script(FILE *f, tupid_t tupid, const char *cmdline,
 	s.exited = 0;
 	s.exit_status = 0;
 	s.signalled = 0;
+	s.need_namespacing = 0;
+	s.run_in_bash = 0;
+	s.streaming_mode = 0;
 	s.error_mutex = NULL;
 	tent = tup_entry_get(tupid);
-	init_file_info(&s.finfo, tup_entry_variant(tent)->variant_dir, 0);
-	if(exec_internal(&s, cmdline, &te, tent, 0, 0, 0) < 0)
+	init_file_info(&s.finfo, 0);
+	if(exec_internal(&s, cmdline, &te, tent, 0) < 0)
 		return -1;
 	environ_free(&te);
 
@@ -782,17 +793,6 @@ int serverless_run_script(FILE *f, const char *cmdline,
 	return -1;
 }
 
-int server_symlink(struct server *s, const char *target, int dfd, const char *linkpath)
-{
-	if(s) {/* unused */}
-	if(symlinkat(target, dfd, linkpath) < 0) {
-		perror("symlinkat");
-		fprintf(stderr, "tup error: unable to create symlink at '%s' pointing to target '%s'\n", linkpath, target);
-		return -1;
-	}
-	return 0;
-}
-
 int server_is_dead(void)
 {
 	return sig_quit;
