@@ -2,7 +2,7 @@
  *
  * tup - A file-based build system
  *
- * Copyright (C) 2008-2021  Mike Shal <marfey@gmail.com>
+ * Copyright (C) 2008-2024  Mike Shal <marfey@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -40,6 +40,7 @@
 #include "flist.h"
 #include "estring.h"
 #include "logging.h"
+#include "luaparser.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -55,6 +56,7 @@ typedef int(*worker_function)(struct graph *g, struct node *n);
 
 static int check_full_deps_rebuild(void);
 static int run_scan(int do_scan);
+static struct tup_entry *get_rel_tent(struct tup_entry *base, struct tup_entry *tent, int do_mkdirs);
 static int process_config_nodes(int environ_check);
 static int process_create_nodes(void);
 static int process_update_nodes(int argc, char **argv, int *num_pruned);
@@ -245,13 +247,17 @@ int generate(int argc, char **argv)
 	struct node *tmp;
 	struct tup_entry *vartent;
 	struct tup_entry *varfiletent;
+	struct tup_entry *orig_vartent;
 	struct tupid_entries generated_dir_root;
+	struct variant *variant;
 	char *script_name = NULL;
 	char *config_file = NULL;
+	char *build_dir = NULL;
 	int verbose_script = 0;
 	int is_batch_script = 0;
 	int x;
 	int rc;
+	int prune_start = -1;
 	const char *file_open_flags = "w";
 	const char *generate_vardict_file = "tup-generate.vardict";
 #ifdef _WIN32
@@ -269,18 +275,28 @@ int generate(int argc, char **argv)
 			x++;
 			config_file = argv[x];
 			continue;
+		} else if(strcmp(argv[x], "--builddir") == 0) {
+			if(x+1 >= argc) {
+				fprintf(stderr, "--builddir requires a directory");
+				return -1;
+			}
+			x++;
+			build_dir = argv[x];
+			continue;
 		} else if(strcmp(argv[x], "--verbose") == 0) {
 			verbose_script = 1;
 			continue;
 		}
-		if(script_name) {
-			fprintf(stderr, "Usage: tup generate [--config config_file] %s\n", example_script);
-			return -1;
-		}
 		script_name = argv[x];
+
+		/* After the script name, any remaining arguments are desired
+		 * outputs that are passed into prune_graph.
+		 */
+		prune_start = x + 1;
+		break;
 	}
 	if(!script_name) {
-		fprintf(stderr, "Usage: tup generate [--config config_file] %s\n", example_script);
+		fprintf(stderr, "Usage: tup generate [--config config_file] [--builddir directory] %s\n", example_script);
 		return -1;
 	}
 #ifdef _WIN32
@@ -308,66 +324,6 @@ int generate(int argc, char **argv)
 		return -1;
 	if(open_tup_top() < 0)
 		return -1;
-	printf("Scanning...\n");
-	if(tup_scan() < 0)
-		return -1;
-
-	tup_db_begin();
-	printf("Reading tup.config...\n");
-	if(tup_db_get_tup_config_tent(&vartent) < 0)
-		return -1;
-	if(variant_add(vartent, 1, NULL) < 0)
-		return -1;
-	if(config_file) {
-		tupid_t sub_dir_dt;
-
-		sub_dir_dt = get_sub_dir_dt();
-		if(sub_dir_dt < 0)
-			return -1;
-		varfiletent = get_tent_dt(sub_dir_dt, config_file);
-		if(!varfiletent) {
-			fprintf(stderr, "Unable to find tupid for: '%s'\n", config_file);
-				return -1;
-		}
-	} else {
-		varfiletent = vartent;
-	}
-	if(tup_db_read_vars(varfiletent->parent, varfiletent->name.s, vartent, generate_vardict_file) < 0)
-		return -1;
-
-	printf("Parsing...\n");
-	if(create_graph(&g, TUP_NODE_DIR) < 0)
-		return -1;
-	if(tup_db_select_node_by_flags(build_graph_cb, &g, TUP_FLAGS_CREATE) < 0)
-		return -1;
-	start_progress(g.num_nodes, g.total_mtime, 1);
-
-	/* The parsing nodes have to be removed so that we know if dependent
-	 * Tupfiles have already been parsed.
-	 */
-	n = TAILQ_FIRST(&g.node_list);
-	if(node_remove_list(&g.node_list, n) < 0)
-		return -1;
-	while(!LIST_EMPTY(&n->edges)) {
-		remove_edge(LIST_FIRST(&n->edges));
-	}
-	remove_node(&g, n);
-
-	TAILQ_FOREACH_SAFE(n, &g.plist, list, tmp) {
-		if(!n->already_used)
-			if(parse(n, &g, NULL, 0, 0, full_deps) < 0)
-				return -1;
-		if(node_remove_list(&g.plist, n) < 0)
-			return -1;
-		while(!LIST_EMPTY(&n->incoming)) {
-			remove_edge(LIST_FIRST(&n->incoming));
-		}
-		remove_node(&g, n);
-	}
-	if(destroy_graph(&g) < 0)
-		return -1;
-
-	printf("Generate: %s\n", script_name);
 	if(chdir(get_tup_top()) < 0) {
 		perror("chdir(get_tup_top())\n");
 		return -1;
@@ -383,17 +339,168 @@ int generate(int argc, char **argv)
 	} else {
 		fprintf(generate_f, "#! /bin/sh -e%s\n", verbose_script ? "x" : "");
 	}
+	fprintf(generate_f, "%s This file is automatically generated with: tup generate", is_batch_script ? "REM" : "#");
+	for(x=0; x<argc; x++) {
+		fprintf(generate_f, " %s", argv[x]);
+	}
+	fprintf(generate_f, "\n");
 #ifdef _WIN32
-	fprintf(generate_f, "set %s=%s\\%s\n", TUP_VARDICT_NAME, get_tup_top(), generate_vardict_file);
+	fprintf(generate_f, "set %s=%%cd%%\\%s\n", TUP_VARDICT_NAME, generate_vardict_file);
 #else
-	fprintf(generate_f, "export %s=\"%s/%s\"\n", TUP_VARDICT_NAME, get_tup_top(), generate_vardict_file);
+	fprintf(generate_f, "export %s=\"$(cd $(dirname $0) && pwd)/%s\"\n", TUP_VARDICT_NAME, generate_vardict_file);
 #endif
+	printf("Scanning...\n");
+	if(tup_scan() < 0)
+		return -1;
+
+	tup_db_begin();
+	printf("Reading tup.config...\n");
+	if(tup_db_get_tup_config_tent(&vartent) < 0)
+		return -1;
+	orig_vartent = vartent;
+
+	if(config_file) {
+		/* If we pass in a config file, point varfiletent to that file.
+		 * We'll read config variables from it.
+		 */
+		tupid_t sub_dir_dt;
+
+		sub_dir_dt = get_sub_dir_dt();
+		if(sub_dir_dt < 0)
+			return -1;
+		varfiletent = get_tent_dt(sub_dir_dt, config_file);
+		if(!varfiletent) {
+			fprintf(stderr, "Unable to find tupid for: '%s'\n", config_file);
+				return -1;
+		}
+	} else {
+		/* No config file passed in, just use the top-level tup.config if any. */
+		varfiletent = vartent;
+	}
+
+	if(build_dir) {
+		/* If we pass in a build dir, create a fake directory there so
+		 * we can generate rules as if it's a variant directory.
+		 * Otherwise we'll build in-tree.
+		 */
+		struct tup_entry *root;
+		struct tup_entry *var_dtent;
+		int changed = 0;
+		int i;
+		for(i=0; i<(signed)strlen(build_dir); i++) {
+			/* The build_dir can actually be multiple path parts
+			 * (like build/sub/dir/), and we don't bother to create
+			 * tup_entry's for each part here since the script
+			 * works fine without doing that. However, we do need
+			 * to convert / to \ for Windows.
+			 */
+			if(build_dir[i] == '/')
+				build_dir[i] = path_sep();
+		}
+		if(tup_entry_add(DOT_DT, &root) < 0)
+			return -1;
+		var_dtent = tup_db_create_node_srcid(root, build_dir, TUP_NODE_DIR, root->tnode.tupid, &changed);
+		if(!var_dtent) {
+			fprintf(stderr, "tup error: Unable to create variant directory entry for build_dir: %s\n", build_dir);
+			return -1;
+		}
+		if(!changed) {
+			fprintf(stderr, "tup error: --builddir directory must be a non-existent directory, but '%s' already exists.\n", build_dir);
+			return -1;
+		}
+		vartent = tup_db_create_node(var_dtent, TUP_CONFIG, TUP_NODE_FILE);
+		if(!vartent) {
+			fprintf(stderr, "tup error: Unable to create tup.config node for build_dir: %s\n", build_dir);
+			return -1;
+		}
+	}
+
+	if(variant_add(vartent, 1, &variant) < 0)
+		return -1;
+	if(!variant->root_variant) {
+		/* Make sure we have a root variant added so the regular
+		 * tup_entrys have somewhere to point.
+		 */
+		if(variant_add(orig_vartent, 0, NULL) < 0)
+			return -1;
+	}
+	if(tup_db_read_vars(varfiletent, vartent, generate_vardict_file) < 0)
+		return -1;
+
+	printf("Parsing...\n");
+	if(create_graph(&g, TUP_NODE_DIR) < 0)
+		return -1;
+	if(tup_db_select_node_by_flags(build_graph_cb, &g, TUP_FLAGS_CREATE) < 0)
+		return -1;
+
+	if(!variant->root_variant) {
+		TAILQ_FOREACH_SAFE(n, &g.plist, list, tmp) {
+			struct variant *node_variant = tup_entry_variant(n->tent);
+			if(node_variant->root_variant) {
+				struct tup_entry *new_tent;
+				new_tent = get_rel_tent(variant->tent->parent, n->tent, 0);
+				if(!new_tent) {
+					fprintf(stderr, "tup internal error: Unable to find directory for variant '%s' for subdirectory: ", variant->variant_dir);
+					print_tup_entry(stderr, n->tent);
+					fprintf(stderr, "\n");
+					return -1;
+				}
+				if(build_graph_cb(&g, new_tent) < 0)
+					return -1;
+				fprintf(generate_f, "mkdir %s", is_batch_script ? "" : "-p ");
+				if(write_tup_entry(generate_f, new_tent) < 0)
+					return -1;
+				fprintf(generate_f, "\n");
+				/* Adjust num_nodes so the progress gets to 100% since we don't parse the root variant. */
+				g.num_nodes--;
+			}
+		}
+	}
+
+	start_progress(g.num_nodes, g.total_mtime, 1);
+
+	/* The parsing nodes have to be removed so that we know if dependent
+	 * Tupfiles have already been parsed.
+	 */
+	n = TAILQ_FIRST(&g.node_list);
+	if(node_remove_list(&g.node_list, n) < 0)
+		return -1;
+	while(!LIST_EMPTY(&n->edges)) {
+		remove_edge(LIST_FIRST(&n->edges));
+	}
+	remove_node(&g, n);
+
+	if(tup_lua_parser_new_state() < 0) {
+		return -1;
+	}
+	TAILQ_FOREACH_SAFE(n, &g.plist, list, tmp) {
+		struct variant *node_variant = tup_entry_variant(n->tent);
+		if(!n->already_used && node_variant->enabled)
+			if(parse(n, &g, NULL, 0, 0, full_deps) < 0)
+				return -1;
+		if(node_remove_list(&g.plist, n) < 0)
+			return -1;
+		while(!LIST_EMPTY(&n->incoming)) {
+			remove_edge(LIST_FIRST(&n->incoming));
+		}
+		remove_node(&g, n);
+	}
+	tup_lua_parser_cleanup();
+	if(destroy_graph(&g) < 0)
+		return -1;
+
+	printf("Generate: %s\n", script_name);
 	if(create_graph(&g, TUP_NODE_CMD) < 0)
 		return -1;
 	if(tup_db_select_node_by_flags(build_graph_cb, &g, TUP_FLAGS_MODIFY) < 0)
 		return -1;
 	if(build_graph(&g) < 0)
 		return -1;
+	if(prune_start != -1) {
+		int num_pruned = 0;
+		if(prune_graph(&g, argc-prune_start, &argv[prune_start], &num_pruned, GRAPH_PRUNE_GENERATED, 0) < 0)
+			return -1;
+	}
 
 	/* Loop through all the nodes and pull out any generated directories.
 	 * The script will 'mkdir' all of these at the top of the script.
@@ -466,7 +573,7 @@ int todo(int argc, char **argv)
 	if(rc < 0)
 		return -1;
 	if(rc == 1) {
-		printf("Run 'tup upd' to bring the system up-to-date.\n");
+		printf("Run 'tup' to bring the system up-to-date.\n");
 		goto out_ok;
 	}
 	printf("tup: Everything is up-to-date.\n");
@@ -671,7 +778,10 @@ static int initialize_server_struct(struct server *s, struct tup_entry *tent)
 	s->output_fd = -1;
 	s->error_fd = -1;
 	s->error_mutex = &display_mutex;
-	if(init_file_info(&s->finfo, tup_entry_variant(tent)->variant_dir, server_unlink()) < 0)
+	s->need_namespacing = 0;
+	s->run_in_bash = 0;
+	s->streaming_mode = 0;
+	if(init_file_info(&s->finfo, server_unlink()) < 0)
 		return -1;
 
 	if(tent->type == TUP_NODE_CMD) {
@@ -932,6 +1042,15 @@ static int process_config_nodes(int environ_check)
 						return -1;
 					rm_node = 0;
 					show_result(n->tent, 0, NULL, "new variant", 1);
+
+					/* Clear out any cached variant fields
+					 * in the tup_entry for us and our
+					 * parent. If the parent directory used
+					 * to be something else, we could fail
+					 * to parse otherwise (t8109).
+					 */
+					n->tent->variant = NULL;
+					n->tent->parent->variant = NULL;
 				} else {
 					if(!variant->enabled) {
 						/* If the variant is disabled
@@ -953,7 +1072,7 @@ static int process_config_nodes(int environ_check)
 				compat_lock_disable();
 				if(initialize_server_struct(&s, n->tent) < 0)
 					goto err_rollback;
-				rc = tup_db_read_vars(n->tent->parent, TUP_CONFIG, n->tent, variant->vardict_file);
+				rc = tup_db_read_vars(n->tent, n->tent, variant->vardict_file);
 				if(handle_file_dtent(ACCESS_READ, n->tent->parent, TUP_CONFIG, &s.finfo) < 0)
 					goto err_rollback;
 				if(rc < 0)
@@ -1041,7 +1160,7 @@ err_rollback:
 	return -1;
 }
 
-static struct tup_entry *get_rel_tent(struct tup_entry *base, struct tup_entry *tent)
+static struct tup_entry *get_rel_tent(struct tup_entry *base, struct tup_entry *tent, int do_mkdirs)
 {
 	struct tup_entry *new;
 	struct tup_entry *sub;
@@ -1050,10 +1169,36 @@ static struct tup_entry *get_rel_tent(struct tup_entry *base, struct tup_entry *
 	if(!tent->parent)
 		return base;
 
-	new = get_rel_tent(base, tent->parent);
+	new = get_rel_tent(base, tent->parent, do_mkdirs);
 	if(!new)
 		return NULL;
 
+	if(tup_db_select_tent(new, tent->name.s, &sub) < 0)
+		return NULL;
+	if(sub) {
+		if(sub->type == TUP_NODE_GENERATED) {
+			/* If we have a generated file in the variant that is
+			 * now a directory, we need to force deleting that
+			 * output now so we can create the directory there
+			 * (t8115).
+			 */
+			if(delete_file(sub) < 0)
+				return NULL;
+			if(tup_del_id_force(sub->tnode.tupid, sub->type) < 0)
+				return NULL;
+		} else if(sub->type == TUP_NODE_GENERATED_DIR) {
+			/* If we have a generated output dir inside the
+			 * variant, just set its type to TUP_NODE_DIR since
+			 * that won't happen in tup_db_create_node_srcid()
+			 * below because of some logic to avoid changing
+			 * generated dir types during the scanning phase
+			 * (t8116).
+			 */
+			if(tup_db_set_type(sub, TUP_NODE_DIR) < 0)
+				return NULL;
+		}
+	}
+
 	sub = tup_db_create_node_srcid(new, tent->name.s, TUP_NODE_DIR, tent->tnode.tupid, &do_mkdir);
 	if(!sub) {
 		fprintf(stderr, "tup error: Unable to create tup node for variant directory: ");
@@ -1061,7 +1206,7 @@ static struct tup_entry *get_rel_tent(struct tup_entry *base, struct tup_entry *
 		fprintf(stderr, "\n");
 		return NULL;
 	}
-	if(do_mkdir) {
+	if(do_mkdir && do_mkdirs) {
 		int fd;
 		fd = tup_entry_open(new);
 		if(fd < 0)
@@ -1126,11 +1271,13 @@ static int gitignore(struct tup_entry *tent)
 		return -1;
 	if(gitignore_tent && gitignore_tent->type == TUP_NODE_GENERATED) {
 		const char *tg_str = "##### TUP GITIGNORE #####\n";
+		int tg_str_len = 26;
 		int tg_idx = 0;
 		int copied_tg_str = 0;
 		char nextchar;
 		struct stat buf;
 		FILE *f;
+		int skip_self = 0;
 		dfd = tup_entry_open(tent);
 		if(dfd < 0)
 			return -1;
@@ -1150,6 +1297,7 @@ static int gitignore(struct tup_entry *tent)
 			goto err_close;
 		}
 		if(fd_old >= 0) {
+			int bytes_copied = 0;
 			while(1) {
 				int rc;
 
@@ -1171,8 +1319,10 @@ static int gitignore(struct tup_entry *tent)
 					perror("fprintf");
 					goto err_close_both;
 				}
-				if(tg_idx == 26) {
+				bytes_copied++;
+				if(tg_idx == tg_str_len) {
 					copied_tg_str = 1;
+					bytes_copied -= tg_str_len;
 					break;
 				}
 			}
@@ -1180,6 +1330,13 @@ static int gitignore(struct tup_entry *tent)
 				perror("close(fd_old)");
 				goto err_close;
 			}
+			if(bytes_copied > 0) {
+				/* If we have some amount of manual user data
+				 * in the file, don't ignore the .gitignore
+				 * file itself.
+				 */
+				skip_self = 1;
+			}
 		}
 		if(!copied_tg_str) {
 			if(fprintf(f, "%s", tg_str) < 0) {
@@ -1201,7 +1358,7 @@ static int gitignore(struct tup_entry *tent)
 				goto err_close;
 			}
 		}
-		if(tup_db_write_gitignore(f, tent->tnode.tupid) < 0)
+		if(tup_db_write_gitignore(f, tent->tnode.tupid, skip_self) < 0)
 			goto err_close;
 		fclose(f);
 		if(renameat(dfd, ".gitignore.new", dfd, ".gitignore") < 0) {
@@ -1283,7 +1440,7 @@ static int process_create_nodes(void)
 				/* Add in all other variants to parse */
 				if(!variant->root_variant) {
 					struct tup_entry *new_tent;
-					new_tent = get_rel_tent(variant->tent->parent, n->tent);
+					new_tent = get_rel_tent(variant->tent->parent, n->tent, 1);
 					if(!new_tent) {
 						fprintf(stderr, "tup internal error: Unable to find directory for variant '%s' for subdirectory: ", variant->variant_dir);
 						print_tup_entry(stderr, n->tent);
@@ -1387,24 +1544,17 @@ static int process_create_nodes(void)
 	if(server_init(SERVER_PARSER_MODE) < 0) {
 		return -1;
 	}
+	if(tup_lua_parser_new_state() < 0) {
+		return -1;
+	}
 	/* create_work must always use only 1 thread since no locking is done */
 	compat_lock_disable();
 	rc = execute_graph(&g, 0, 1, create_work);
 	compat_lock_enable();
 
+	tup_lua_parser_cleanup();
+
 	if(rc == 0) {
-		if(g.gen_delete_root.count) {
-			tup_main_progress("Deleting files...\n");
-		} else {
-			tup_main_progress("No files to delete.\n");
-		}
-		rc = delete_files(&g);
-		if(rc == 0 && group_need_circ_check()) {
-			/* TODO: Extra space */
-			tup_show_message("Checking circular dependencies among groups...\n");
-			if(group_circ_check() < 0)
-				rc = -1;
-		}
 		if(rc == 0 && !RB_EMPTY(&g.normal_dir_root)) {
 			int msg_shown = 0;
 			while(!RB_EMPTY(&g.normal_dir_root)) {
@@ -1434,9 +1584,31 @@ static int process_create_nodes(void)
 					 */
 					if(tent_tree_add_dup(&g.parse_gitignore_root, tent->parent) < 0)
 						return -1;
+					/* And remove extra gitignore file in
+					 * the generated folder (t2245)
+					 */
+					struct tup_entry *gitignore_tent;
+					if(tup_db_select_tent(tent, ".gitignore", &gitignore_tent) < 0)
+						return -1;
+					if(gitignore_tent && gitignore_tent->type == TUP_NODE_GENERATED) {
+						tent_tree_add(&g.gen_delete_root, gitignore_tent);
+						if(remove_tup_gitignore(stderr, &g, gitignore_tent) < 0)
+							return -1;
+					}
 				}
 			}
 		}
+		if(g.gen_delete_root.count) {
+			tup_main_progress("Deleting files...\n");
+		} else {
+			tup_main_progress("No files to delete.\n");
+		}
+		rc = delete_files(&g);
+		if(rc == 0 && group_need_circ_check()) {
+			tup_show_message("Checking circular dependencies among groups...\n");
+			if(group_circ_check() < 0)
+				rc = -1;
+		}
 		if(rc == 0 && !RB_EMPTY(&g.parse_gitignore_root) && !refactoring) {
 			tup_show_message("Generating .gitignore files...\n");
 			RB_FOREACH(tt, tent_entries, &g.parse_gitignore_root) {
@@ -2054,7 +2226,6 @@ static int update_work(struct graph *g, struct node *n)
 
 static int generate_work(struct graph *g, struct node *n)
 {
-	int rc = 0;
 	char *expanded_name = NULL;
 	struct tent_entries sticky_root = TENT_ENTRIES_INITIALIZER;
 	struct tent_entries normal_root = TENT_ENTRIES_INITIALIZER;
@@ -2063,36 +2234,34 @@ static int generate_work(struct graph *g, struct node *n)
 
 	if(n->tent->type == TUP_NODE_CMD) {
 		const char *cmd;
-		if(generate_cwd != n->tent->parent) {
+		struct tup_entry *srctent = variant_tent_to_srctent(n->tent->parent);
+		if(generate_cwd != srctent) {
 			fprintf(generate_f, "cd \"");
-			if(get_relative_dir(generate_f, NULL, generate_cwd->tnode.tupid, n->tent->dt) < 0) {
-				rc = -1;
-			} else {
-				fprintf(generate_f, "\"\n");
-				generate_cwd = n->tent->parent;
+			if(get_relative_dir(generate_f, NULL, generate_cwd->tnode.tupid, srctent->tnode.tupid) < 0) {
+				return -1;
 			}
+			fprintf(generate_f, "\"\n");
+			generate_cwd = srctent;
 		}
 		cmd = n->tent->name.s;
-		rc = tup_db_get_inputs(n->tent->tnode.tupid, &sticky_root, &normal_root, &group_sticky_root);
-		if (rc == 0) {
-			if(expand_command(&expanded_name, n->tent, cmd, &group_sticky_root, NULL) < 0) {
-				fprintf(stderr, "tup error: Failed to expand command '%s' for generate script.\n", n->tent->name.s);
-				rc = -1;
-			}
-			if(expanded_name)
-				cmd = expanded_name;
+		if(tup_db_get_inputs(n->tent->tnode.tupid, &sticky_root, &normal_root, &group_sticky_root) < 0) {
+			return -1;
 		}
+		if(expand_command(&expanded_name, n->tent, cmd, &group_sticky_root, NULL) < 0) {
+			fprintf(stderr, "tup error: Failed to expand command '%s' for generate script.\n", n->tent->name.s);
+			return -1;
+		}
+		if(expanded_name)
+			cmd = expanded_name;
 		free_tent_tree(&sticky_root);
 		free_tent_tree(&normal_root);
 		free_tent_tree(&group_sticky_root);
 		if(cmd)
 			fprintf(generate_f, "(%s)\n", cmd);
 		free(expanded_name);
-	} else {
-		rc = 0;
 	}
 
-	return rc;
+	return 0;
 }
 
 static int todo_work(struct graph *g, struct node *n)
@@ -2175,6 +2344,8 @@ static int restore_outputs(struct node *n)
 	LIST_FOREACH(e, &n->edges, list) {
 		output = e->dest;
 		if(!skip_output(output->tent)) {
+			struct stat buf;
+
 			curpath[0] = '.';
 			if(snprint_tup_entry(curpath+1, sizeof(curpath)-1, output->tent) >= (int)sizeof(curpath)-1) {
 				fprintf(stderr, "tup error: curpath sized incorrectly in move_outputs()\n");
@@ -2195,6 +2366,17 @@ static int restore_outputs(struct node *n)
 					return -1;
 				}
 			}
+
+			if(lstat(curpath, &buf) == 0) {
+				if(tup_db_set_mtime(output->tent, MTIME(buf)) < 0)
+					return -1;
+			} else {
+				/* ENOENT is ok, similar to above. */
+				if(errno != ENOENT) {
+					fprintf(stderr, "tup error: Unable to lstat() output '%s' after restoring it.\n", curpath);
+					return -1;
+				}
+			}
 		}
 	}
 	return 0;
@@ -2426,7 +2608,7 @@ static int process_output(struct server *s, struct node *n,
 	FILE *f;
 	int is_err = 1;
 	struct timespan *show_ts = NULL;
-	time_t ms = -1;
+	struct timespec ms = {-1, 0};
 	struct tup_entry *tent = n->tent;
 	int *warning_dest;
 	int important_link_removed = 0;
@@ -2449,7 +2631,7 @@ static int process_output(struct server *s, struct node *n,
 			if(write_files(f, tent->tnode.tupid, &s->finfo, warning_dest, CHECK_SUCCESS, full_deps, tup_entry_vardt(tent), &important_link_removed) == 0) {
 				timespan_end(ts);
 				show_ts = ts;
-				ms = timespan_milliseconds(ts);
+				ms.tv_sec = timespan_milliseconds(ts);
 
 				/* Hooray! */
 				is_err = 0;
@@ -2526,7 +2708,7 @@ static int process_output(struct server *s, struct node *n,
 
 	if(is_err)
 		return -1;
-	if(tent->mtime != ms)
+	if(tent->mtime.tv_sec != ms.tv_sec)
 		if(tup_db_set_mtime(tent, ms) < 0)
 			return -1;
 	return 0;
@@ -2566,7 +2748,7 @@ static int expand_group(FILE *f, struct estring *e, struct expand_info *info)
 					if(e && !first)
 						if(estring_append(e, " ", 1) < 0)
 							return -1;
-					if(get_relative_dir(f, e, info->tent->parent->tnode.tupid, input_tent->tnode.tupid) < 0)
+					if(get_relative_dir(f, e, variant_tent_to_srctent(info->tent->parent)->tnode.tupid, input_tent->tnode.tupid) < 0)
 						return -1;
 					if(f)
 						fprintf(f, "\n");
@@ -2704,7 +2886,7 @@ static int expand_command(char **res,
 	return 0;
 }
 
-static const char *input_and_output_from_cmd(const char *cmd, struct tup_entry *dtent, char *input, char *output)
+static const char *input_and_output_from_cmd(const char *cmd, char *input)
 {
 	const char *endp;
 	size_t input_len;
@@ -2720,58 +2902,41 @@ static const char *input_and_output_from_cmd(const char *cmd, struct tup_entry *
 	input[input_len] = 0;
 	while(isspace(*endp))
 		endp++;
-	if(is_full_path(endp)) {
-		strcpy(output, endp);
-	} else {
-		output[0] = '.';
-		snprint_tup_entry(output+1, PATH_MAX-1, dtent);
-		strcat(output, "/");
-		strcat(output, endp);
-	}
 	return endp;
 }
 
-static int specify_pseudo_exec_output(struct server *s, const char *output)
-{
-	struct mapping *map;
-	if(handle_file(ACCESS_WRITE, output, NULL, &s->finfo) < 0)
-		return -1;
-	map = malloc(sizeof *map);
-	if(!map) {
-		perror("malloc");
-		return -1;
-	}
-	map->realname = strdup(output);
-	map->tmpname = strdup(output);
-	map->tent = NULL;
-	finfo_lock(&s->finfo);
-	TAILQ_INSERT_TAIL(&s->finfo.mapping_list, map, list);
-	finfo_unlock(&s->finfo);
-
-	s->exited = 1;
-	s->exit_status = 0;
-	return 0;
-}
-
 static int do_ln(struct server *s, struct tup_entry *dtent, int dfd, const char *cmd)
 {
 	char input_path[PATH_MAX];
-	char full_output_path[PATH_MAX];
-	const char* output_name = input_and_output_from_cmd(cmd, dtent, input_path, full_output_path);
+	const char* output_name = input_and_output_from_cmd(cmd, input_path);
+	struct tup_entry *output_tent = NULL;
+	struct tent_tree *tt;
+	RB_FOREACH(tt, tent_entries, &s->finfo.output_root) {
+		if(output_tent) {
+			fprintf(stderr, "tup internal error: tup symlink command has multiple output files. Command: ");
+			print_tup_entry(stderr, dtent);
+			fprintf(stderr, "\n");
+			return -1;
+		}
+		output_tent = tt->tent;
+	}
 	if(!output_name)
 		return -1;
-	if(server_symlink(s, input_path, dfd, output_name) < 0)
+	if(server_symlink(s, dtent, input_path, dfd, output_name, output_tent) < 0)
 		return -1;
-	return specify_pseudo_exec_output(s, full_output_path);
+	s->exited = 1;
+	s->exit_status = 0;
+	return 0;
 }
 
 static int update(struct node *n)
 {
-	int dfd = -1;
+	int dfd;
+	int srcdfd;
 	char *expanded_name = NULL;
 	const char *cmd;
 	struct server s;
-	int rc;
+	int rc = 0;
 	struct tup_env newenv;
 	struct timespan ts;
 	int need_namespacing = 0;
@@ -2779,6 +2944,8 @@ static int update(struct node *n)
 	int run_in_bash = 0;
 	int use_server = 0;
 	int remove_transients = 0;
+	int streaming_mode = 0;
+	int is_variant;
 
 	timespan_start(&ts);
 	if(n->tent->flags) {
@@ -2794,9 +2961,15 @@ static int update(struct node *n)
 				case 'b':
 					run_in_bash = 1;
 					break;
+				case 'j':
+					/* Only used for compile_commands.json */
+					break;
 				case 't':
 					remove_transients = 1;
 					break;
+				case 's':
+					streaming_mode = 1;
+					break;
 				default:
 					pthread_mutex_lock(&display_mutex);
 					show_result(n->tent, 1, NULL, NULL, 1);
@@ -2827,7 +3000,24 @@ static int update(struct node *n)
 	}
 
 	pthread_mutex_lock(&db_mutex);
-	rc = initialize_server_struct(&s, n->tent);
+	is_variant = !tup_entry_variant(n->tent->parent)->root_variant;
+	if(is_variant) {
+		srcdfd = tup_entry_open(variant_tent_to_srctent(n->tent->parent));
+		if(srcdfd < 0) {
+			pthread_mutex_lock(&display_mutex);
+			fprintf(stderr, "tup error: Unable to open srcdir directory for update work.\n");
+			pthread_mutex_unlock(&display_mutex);
+			rc = -1;
+		}
+	} else {
+		srcdfd = dfd;
+	}
+	if(rc == 0) {
+		rc = initialize_server_struct(&s, n->tent);
+		s.need_namespacing = need_namespacing;
+		s.run_in_bash = run_in_bash;
+		s.streaming_mode = streaming_mode;
+	}
 	if(rc == 0)
 		rc = tup_db_get_environ(&s.finfo.sticky_root, &s.finfo.normal_root, &newenv);
 	if(rc == 0) {
@@ -2838,13 +3028,13 @@ static int update(struct node *n)
 	}
 	pthread_mutex_unlock(&db_mutex);
 	if(rc < 0)
-		goto err_close_dfd;
+		goto err_close_srcdfd;
 	if(strncmp(cmd, "!tup_ln ", 8) == 0) {
-		rc = do_ln(&s, n->tent->parent, dfd, cmd + 8);
+		rc = do_ln(&s, n->tent->parent, srcdfd, cmd + 8);
 	} else if (strncmp(cmd, "!tup_preserve ", 14) == 0) {
-		rc = do_ln(&s, n->tent->parent, dfd, cmd + 14);
+		rc = do_ln(&s, n->tent->parent, srcdfd, cmd + 14);
 	} else {
-		rc = server_exec(&s, dfd, cmd, &newenv, n->tent->parent, need_namespacing, run_in_bash);
+		rc = server_exec(&s, srcdfd, cmd, &newenv, n->tent->parent);
 		use_server = 1;
 	}
 	if(rc < 0) {
@@ -2852,9 +3042,15 @@ static int update(struct node *n)
 		fprintf(stderr, " *** Command ID=%lli failed: %s\n", n->tnode.tupid, cmd);
 		pthread_mutex_unlock(&display_mutex);
 		free(expanded_name);
-		goto err_close_dfd;
+		goto err_close_srcdfd;
 	}
 	environ_free(&newenv);
+	if(is_variant) {
+		if(close(srcdfd) < 0) {
+			perror("close(srcdfd)");
+			return -1;
+		}
+	}
 	if(close(dfd) < 0) {
 		perror("close(dfd)");
 		return -1;
@@ -2876,6 +3072,12 @@ static int update(struct node *n)
 			return -1;
 	return rc;
 
+err_close_srcdfd:
+	if(is_variant) {
+		if(close(srcdfd) < 0) {
+			perror("close(srcdfd");
+		}
+	}
 err_close_dfd:
 	if(close(dfd) < 0) {
 		perror("close(dfd)");
