@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,10 +19,11 @@
 # Make sure ../.. doesn't get condensed to nothing.
 
 . ./tup.sh
-tmkdir foo
+mkdir foo
 cd foo
-tmkdir baz
+mkdir baz
 cd baz
+tup scan
 tup touch ../../bar.c
 tup touch ../baz/../../foo.c
 cd ../..
