@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,7 +19,7 @@
 # Make sure 'tup graph .' doesn't crash, since it has a slightly different code
 # path that is not normally exercised.
 . ./tup.sh
-tup touch foo.c
+touch foo.c
 tup graph . > /dev/null
 
 eotup
