@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2008-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2008-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -21,7 +21,7 @@
 # directory).
 
 . ./tup.sh
-tmkdir a
+mkdir a
 cat > a/Tupfile << HERE
 include ../Tupfile.vars
 : foreach *.c |> \$(CC) -c %f -o %o \$(CCARGS) |> %B.o
@@ -38,7 +38,7 @@ CCARGS := -DFOO=1
 CCARGS += -DBAR=1
 HERE
 
-tup touch a/foo.c a/bar.c a/Tupfile Tupfile.vars Tupfile.ccargs
+touch a/foo.c a/bar.c
 parse
 tup_object_exist a foo.c bar.c
 tup_object_exist a "gcc -c foo.c -o foo.o -DFOO=1 -DBAR=1"
