@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -24,9 +24,9 @@ cat > Tupfile << HERE
 : foreach subdir/*.txt |> cp %f %o |> %b
 : foreach subdir/*.c |> gcc -c %f -o %o |> %B.o
 HERE
-tmkdir subdir
-tmkdir superlongtest
-tup touch subdir/foo.c subdir/readme.txt Tupfile superlongtest/ok
+mkdir subdir
+mkdir superlongtest
+touch subdir/foo.c subdir/readme.txt superlongtest/ok
 parse
 tup_object_exist . foo.o readme.txt
 tup_object_exist . "cp subdir/readme.txt readme.txt"
