@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,11 +19,10 @@
 # Simple test to write to a file in another directory.
 
 . ./tup.sh
-tmkdir bar
+mkdir bar
 cat > Tupfile << HERE
 : |> echo hey > %o |> bar/foo.o
 HERE
-tup touch Tupfile
 update
 
 eotup
