@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -21,12 +21,17 @@
 . ./tup.sh
 cat > Tupfile << HERE
 : |> echo blah > %o |> foo.h
-: foreach *.c | foo.h |> echo gcc -c %f -o %o |> %B.o
+: foreach *.c | foo.h nongen.h |> echo gcc -c %f -o %o |> %B.o
 HERE
 
-tup touch Tupfile foo.c bar.c
+touch foo.c bar.c nongen.h
 parse
 tup_sticky_exist . foo.h . "echo gcc -c foo.c -o foo.o"
 tup_sticky_exist . foo.h . "echo gcc -c bar.c -o bar.o"
 
+# We should have a sticky on the normal %f file, but not the normal order-only
+# input file.
+tup_sticky_exist . foo.c . "echo gcc -c foo.c -o foo.o"
+tup_sticky_no_exist . nongen.h . "echo gcc -c foo.c -o foo.o"
+
 eotup
