@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -22,7 +22,7 @@
 cat > Tupfile << HERE
 : foo.c |> sh -c "gcc -c %f -o %o" |> %B.o
 HERE
-tup touch foo.c Tupfile
+touch foo.c
 parse
 tup_object_exist . foo.c
 tup_object_exist . "sh -c \"gcc -c foo.c -o foo.o\""
