@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,10 +23,9 @@
 cat > Tupfile << HERE
 : foo.c |> gcc -c foo.c -o foo.o |> bar/foo.o
 HERE
-tmkdir bar
-tup touch bar/hey
+mkdir bar
+touch bar/hey
 touch foo.c
-tup touch foo.c Tupfile
 update_fail
 
 eotup
