@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,7 +23,7 @@ cat > Tupfile << HERE
 : foreach *.c | foo.h |> echo gcc -c %f -o %o |> %B.o
 HERE
 
-tup touch Tupfile foo.c bar.c
+touch foo.c bar.c
 parse_fail_msg "Explicitly named file 'foo.h' not found"
 
 eotup
