@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -25,13 +25,11 @@ cat > Tupfile << HERE
 HERE
 
 echo hey > foo.txt
-tup touch Tupfile foo.txt
 update
 
 cat > Tupfile << HERE
 : bar.txt |> cat %f |>
 HERE
-tup touch Tupfile
 update_fail
 
 eotup
