@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -21,12 +21,12 @@
 
 . ./tup.sh
 touch foo
-tup touch foo
+tup scan
 rm foo
-tup rm foo
+tup scan
 
-tmkdir foo
+mkdir foo
 touch foo/bar
-tup touch foo/bar
+update
 
 eotup
