@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -26,19 +26,17 @@
 # that it should error on the fact that it was a generated file.
 
 . ./tup.sh
-tmkdir foo
+mkdir foo
 cat > foo/Tupfile << HERE
 : |> echo "var=foo" > %o |> inc
 HERE
 touch Tupfile
 
-tup touch Tupfile foo/Tupfile
 update
 
 cat > Tupfile << HERE
 include foo/inc
 HERE
-tup touch Tupfile
 update_fail
 
 eotup
