@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -28,7 +28,7 @@ cat > Tupfile << HERE
 : |> echo foo > %o |> bar
 HERE
 
-tup touch Tupfile order.h
+touch order.h
 parse
 tup_object_no_exist . "nope"
 tup_object_no_exist . "not gonna work"
