@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -26,7 +26,6 @@ cat > Tupfile << HERE
 : |> ./ok.sh > %o |> output.txt
 HERE
 chmod +x ok.sh
-tup touch ok.sh Tupfile
 update
 echo nofile | diff output.txt -
 
@@ -35,7 +34,6 @@ cat > Tupfile << HERE
 : ghost |> ./ok.sh > %o |> output.txt
 HERE
 
-tup touch Tupfile
 update
 echo alive | diff output.txt -
 
