@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -30,16 +30,13 @@ cat > Tupfile << HERE
 HERE
 chmod +x ok.sh
 ln -s ghost foo
-tup touch foo ok.sh Tupfile
 update
 echo nofile | diff output.txt -
 
 rm -f foo
-tup rm foo
 tup_object_exist . ghost
 
 echo 'alive' > ghost
-tup touch ghost
 update
 echo alive | diff output.txt -
 
