@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -25,7 +25,7 @@ cat > Tupfile << HERE
 : {objs} |> gcc %f -o %o |> prog
 : *.o |> test %f |>
 HERE
-tup touch foo.c bar.c Tupfile
+touch foo.c bar.c
 parse
 tup_sticky_exist . 'foo.o' . 'gcc foo.o bar.o -o prog'
 tup_sticky_exist . 'bar.o' . 'gcc foo.o bar.o -o prog'
