@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -22,7 +22,7 @@
 cat > Tupfile << HERE
 : foreach foo.c bar.c |> gcc -c %f -o %o |> %B.o {objs} {blah}
 HERE
-tup touch foo.c bar.c Tupfile
+touch foo.c bar.c
 parse_fail_msg "bin must be at the end of the output list"
 
 eotup
