@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,8 +19,8 @@
 # Make sure a dependent Tupfile that fails still gets re-parsed.
 
 . ./tup.sh
-tmkdir foo
-tmkdir bar
+mkdir foo
+mkdir bar
 cat > foo/Tupfile << HERE
 : |> echo yo > %o |> yo.h
 HERE
@@ -28,7 +28,7 @@ cat > bar/Tupfile << HERE
 : ../foo/*.txt |> cp %f %o |> output
 : ../foo/*.c |> cp %f %o |> output
 HERE
-tup touch foo/Tupfile bar/Tupfile foo/ok.txt
+touch foo/ok.txt
 update
 
 # Change yo.h to yo.c so the second rule in bar/Tupfile is triggered to also
@@ -36,7 +36,6 @@ update
 cat > foo/Tupfile << HERE
 : |> echo yo > %o |> yo.c
 HERE
-tup touch foo/Tupfile
 update_fail
 
 # An update should again try to parse bar and fail again.
