@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -32,7 +32,6 @@ HERE
 gcc ok.c -o ok.exe
 ./ok.exe > Tupfile
 
-tup touch Tupfile ok.c ok.exe
 update
 check_exist foo
 
@@ -52,7 +51,6 @@ HERE
 gcc ok.c -o ok.exe
 ./ok.exe > Tupfile
 
-tup touch Tupfile
 update
 check_exist bar
 
