@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,15 +19,14 @@
 # Include multiple subdirectories of Tupfiles
 
 . ./tup.sh
-tmkdir sub1
-tmkdir sub1/sub2
-tmkdir sub1/sub2/sub3
+mkdir sub1
+mkdir sub1/sub2
+mkdir sub1/sub2/sub3
 
 echo 'include sub1/1.tup' > Tupfile
 echo 'include sub2/2.tup' > sub1/1.tup
 echo 'include sub3/3.tup' > sub1/sub2/2.tup
 echo 'cflags += -DFOO' > sub1/sub2/sub3/3.tup
-tup touch Tupfile sub1/1.tup sub1/sub2/2.tup sub1/sub2/sub3/3.tup
 update
 
 eotup
