@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,11 +23,10 @@
 cat > Tupfile << HERE
 : |> touch %o |> foo
 HERE
-tmkdir sub
+mkdir sub
 cat > sub/Tupfile << HERE
 : |> touch %o |> bar
 HERE
-tup touch Tupfile sub/Tupfile
 update
 
 check_exist foo sub/bar
@@ -42,7 +41,7 @@ cat > sub/Tupfile << HERE
 : |> touch %o |> bar2
 HERE
 
-# Don't tup touch the Tupfiles - the parser version should cause them to update
+# Don't touch the Tupfiles - the parser version should cause them to update
 update > .tupoutput
 if ! grep 'Tup parser version has been updated' .tupoutput > /dev/null; then
 	echo "*** Expected the parser version update message to be displayed, but it wasn't." 1>&2
