@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -30,7 +30,7 @@ chmod +x gen.sh
 cat > Tupfile << HERE
 run ./gen.sh
 HERE
-tup touch Tupfile gen.sh foo.c bar.c
+touch foo.c bar.c
 update
 
 check_exist foo.o bar.o
@@ -39,7 +39,6 @@ check_exist foo.o bar.o
 cat > gen.sh << HERE
 #! /bin/sh
 HERE
-tup touch gen.sh
 update
 
 check_not_exist foo.o bar.o
@@ -48,7 +47,6 @@ tup_dep_exist . gen.sh 0 .
 # Now don't call gen.sh and make sure the dependency on the directory is gone.
 cat > Tupfile << HERE
 HERE
-tup touch Tupfile
 update
 
 tup_dep_no_exist . gen.sh 0 .
