@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -35,7 +35,7 @@ chmod +x gen.sh
 cat > Tupfile << HERE
 run ./gen.sh
 HERE
-tup touch a.in b.in c.in Tupfile
+touch a.in b.in c.in
 parse_fail_msg "Missing newline from :-rule in run script"
 
 eotup
