@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -21,8 +21,8 @@
 . ./tup.sh
 check_no_windows run-script
 
-tmkdir sw
-tmkdir tools
+mkdir sw
+mkdir tools
 
 cat > Tuprules.tup << HERE
 &script = tools/script.sh
@@ -40,9 +40,6 @@ HERE
 
 chmod u+x tools/script.sh
 
-tup touch Tuprules.tup
-tup touch sw/Tupfile
-tup touch tools/script.sh
 update
 
 tup_dep_exist tools script.sh . sw
