@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -16,18 +16,20 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-# Test that using a node-variable as the lval in an if statement doesn't work.
+# Test that using a node-variable in an if-statement works.
 
 . ./tup.sh
 
 cat > Tupfile << HERE
 &node_var = lib.a
-ifeq (&(node_var),)
+&other_var = lib.a
+ifeq (&(node_var),&(other_var))
+: |> touch %o |> foo.txt
 endif
 HERE
+touch lib.a
+update
 
-tup touch lib.a Tupfile
-
-update_fail_msg "&-variables not allowed here"
+check_exist foo.txt
 
 eotup
