@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -27,7 +27,7 @@ node_var += new value
 : |> echo &(node_var) is \$(node_var) |>
 HERE
 
-tup touch lib.a Tupfile
+touch lib.a
 update
 
 tup_object_exist . 'echo lib.a is new value'
