@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -26,7 +26,7 @@ cat > Tupfile << HERE
 : |> echo &(libs) > %o |> out.txt
 HERE
 
-tup touch Tupfile foo.a bar.a
+touch foo.a bar.a
 update
 
 tup_object_exist . 'echo foo.a bar.a > out.txt'
