@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -22,7 +22,7 @@
 . ./tup.sh
 check_no_windows slashes
 
-tmkdir lib
+mkdir lib
 
 cat > lib/Tupfile << HERE
 : |> touch %o |> lib.a
@@ -38,7 +38,6 @@ include &(lib)
 : foreach \$(static_libs) |> cp %f %o |> %b.copy
 HERE
 
-tup touch Tupfile lib/Tupfile lib/lib.tup
 update
 
 tup_dep_exist lib lib.a . 'cp lib/lib.a lib.a.copy'
