@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -24,8 +24,8 @@ cat > Tupfile << HERE
 : |> echo foo > %o |> bar.txt
 HERE
 
-tmkdir sub
-tmkdir sub/dir
+mkdir sub
+mkdir sub/dir
 
 cat > sub/dir/Tupfile << HERE
 preload ../..
