@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -20,9 +20,9 @@
 
 . ./tup.sh
 
-tmkdir sw
-tmkdir sw/toolkit
-tmkdir sw/app
+mkdir sw
+mkdir sw/toolkit
+mkdir sw/app
 
 cat > sw/Tuprules.lua << HERE
 toolkit_lib = tup.nodevariable('toolkit/toolkit.a')
@@ -32,9 +32,7 @@ cat > sw/app/Tupfile.lua << HERE
 tup.definerule{command = 'cp ' .. toolkit_lib .. ' lib_copy.a', outputs = {'lib_copy.a'}}
 HERE
 
-tup touch sw/Tuprules.lua
-tup touch sw/toolkit/toolkit.a
-tup touch sw/app/Tupfile.lua
+touch sw/toolkit/toolkit.a
 update
 
 tup_dep_exist sw/toolkit toolkit.a sw/app "cp ../toolkit/toolkit.a lib_copy.a"
