@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -24,8 +24,7 @@ CFLAGS += '-DFOO'
 CFLAGS += '-DBAR'
 print("My cflags are: ", tostring(CFLAGS))
 HERE
-tup touch Tupfile.lua
-tup parse > .output.txt
+parse > .output.txt
 if ! grep 'My cflags are:.*-DFOO -DBAR' .output.txt > /dev/null; then
 	cat .output.txt
 	echo "Error: Expecting CFLAGS to be expanded"
