@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -27,7 +27,7 @@ tup.rule(nil, 'echo hey > %o', 'menu.inc')
 tup.foreach_rule(pages, 'cp %f %o', '%b.gen')
 HERE
 
-tup touch Tupfile.lua foo.html bar.html hey.txt
+touch foo.html bar.html hey.txt
 parse
 
 tup_object_exist . 'cp foo.html foo.html.gen'
