@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,7 +19,7 @@
 # Read from a data file with lua in a subdir.
 
 . ./tup.sh
-tmkdir sub
+mkdir sub
 cat > sub/data.txt << HERE
 foo
 bar
@@ -43,7 +43,6 @@ foo
 bar
 baz
 HERE
-tup touch sub/data.txt
 update
 
 check_exist sub/foo sub/bar sub/baz
