@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -30,7 +30,7 @@ cat > build.lua << HERE
 files += 'foo.c'
 tup.foreach_rule(files, '\$(CC) \$(CFLAGS) -c %f -o %o', '%B.o')
 HERE
-tup touch foo.c
+touch foo.c
 update
 
 tup_object_exist . 'gcc -DFOO -DBAR -DBAZ -c foo.c -o foo.o'
