@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,11 +23,11 @@
 cat > build.tup << HERE
 : |> touch %o |> %d.lib
 HERE
-tmkdir foo
+mkdir foo
 cat > foo/Tupfile << HERE
 include ../build.tup
 HERE
-tmkdir bar
+mkdir bar
 cat > bar/Tupfile << HERE
 include ../build.tup
 HERE
