@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2014-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2014-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,8 +19,8 @@
 # Check tup.getrelativedir() with a bad directory.
 
 . ./tup.sh
-tmkdir foo
-tmkdir foo/bar
+mkdir foo
+mkdir foo/bar
 cat > Tupdefault.lua << HERE
 tup.rule("echo " .. tup.getrelativedir(nil))
 HERE
