@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2014-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2014-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,9 +23,9 @@
 cat > Tupfile << HERE
 : file1.ext file2.ext foo/file3.ext file4.ext foo/file5.ext |> cmd %1f %3f %2o %1o %4B %5b |> out1 out2
 HERE
-tmkdir foo
-tup touch file1.ext file2.ext file4.ext
-tup touch foo/file3.ext foo/file5.ext
+mkdir foo
+touch file1.ext file2.ext file4.ext
+touch foo/file3.ext foo/file5.ext
 parse
 
 tup_object_exist . 'cmd file1.ext foo/file3.ext out2 out1 file4 file5.ext'
