@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2014-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2014-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,9 +19,9 @@
 # Try some failure cases in %1f
 
 . ./tup.sh
-tup touch file1 file2
-tmkdir foo
-tup touch foo/file3
+touch file1 file2
+mkdir foo
+touch foo/file3
 
 cat > Tupfile << HERE
 : file1 file2 foo/file3 |> cmd %0o |> out1 out2
