@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2014-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2014-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -30,8 +30,8 @@ libs += l3
 libs += l4
 : test1 \$(files) \$(libs) |> cmd T %1f F %2f b %2b B %2B L %3f O %1o 2 %2o |> \$(empty) out2
 HERE
-tmkdir f
-tup touch test1 f1.e f2.e f3.e f/f4.e l1 l2 l3 l4
+mkdir f
+touch test1 f1.e f2.e f3.e f/f4.e l1 l2 l3 l4
 parse
 
 tup_object_exist . 'cmd T test1 F f1.e f2.e f3.e f/f4.e b f1.e f2.e f3.e f4.e B f1 f2 f3 f4 L l1 l2 l3 l4 O  2 out2'
