@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2010-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2010-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -21,7 +21,7 @@
 
 . ./tup.sh
 
-cat > Tuprules.lua << HERE
+cat > rules.lua << HERE
 tup.include('compile.lua')
 LINUX_ROOT = tup.getcwd()
 HERE
@@ -34,6 +34,7 @@ end
 HERE
 
 cat > root.lua << HERE
+tup.include('rules.lua')
 cc_linux('*.c')
 HERE
 
@@ -46,8 +47,8 @@ include_rules
 include \$(GITTUP_ROOT)/root.lua
 HERE
 
-tmkdir build
-tup touch foo.c build/tup.config
+mkdir build
+touch foo.c build/tup.config
 update
 
 eotup
