@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2015-2020  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2015-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,13 +23,13 @@
 cat > Tupfile << HERE
 : foreach *.txt |> !tup_ln |> %B.lnk
 HERE
-tup touch foo.txt bar.txt
+touch foo.txt bar.txt
 
-tmkdir sub
+mkdir sub
 cat > sub/Tupfile << HERE
 : foreach *.txt |> !tup_ln |> %B.lnk
 HERE
-tup touch sub/baz.txt sub/blah.txt
+touch sub/baz.txt sub/blah.txt
 update
 
 tup_dep_exist . "$(tup_ln_cmd foo.txt foo.lnk)" . foo.lnk
