@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2015-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2015-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,7 +23,7 @@
 cat > Tupfile.lua << HERE
 tup.foreach_rule('*.txt', '!tup_ln', '%B.lnk')
 HERE
-tup touch foo.txt bar.txt
+touch foo.txt bar.txt
 update
 
 tup_dep_exist . "$(tup_ln_cmd foo.txt foo.lnk)" . foo.lnk
