@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2016-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2016-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -21,14 +21,14 @@
 . ./tup.sh
 check_no_windows paths
 
-tmkdir sub
+mkdir sub
 cat > sub/Tupfile << HERE
 : `pwd -P`/foo/input.txt |> !tup_ln |> link.txt
 HERE
-tmkdir foo
-tup touch foo/input.txt
+mkdir foo
+touch foo/input.txt
 update
 
-tup_dep_exist sub "!tup_ln `pwd -P`/foo/input.txt link.txt" sub link.txt
+tup_dep_exist sub "!tup_ln ../foo/input.txt link.txt" sub link.txt
 
 eotup
