@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2017-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2017-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -20,7 +20,7 @@
 # output list.
 
 . ./tup.sh
-tup touch foo bar
+touch foo bar
 cat > Tupfile << HERE
 : |> touch %o |> foo bar
 HERE
