@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2020-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2020-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -29,7 +29,7 @@ cleanup()
 	rm -rf $tmpdir
 }
 
-trap cleanup INT TERM
+trap cleanup EXIT INT TERM
 cleanup
 mkdir $tmpdir
 cd $tmpdir
@@ -67,7 +67,4 @@ if ! grep "$expected" $generate_script_name > /dev/null; then
 	exit 1
 fi
 
-cleanup
-cd $tupcurdir
-
 eotup
