@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2021-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -29,8 +29,6 @@ update
 
 gitignore_good foo .gitignore
 
-tup touch .gitignore
-tup touch Tupfile
 parse > .tup/output.txt 2>&1
 
 if grep 'generated -> normal: .gitignore' .tup/output.txt > /dev/null; then
