@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -25,7 +25,6 @@ cat > Tupfile << HERE
 HERE
 echo "hey @FOO@ yo" > foo.txt
 echo "This is an email@address.com" >> foo.txt
-tup touch foo.txt Tupfile
 varsetall FOO=sup
 update
 tup_object_exist . foo.txt out.txt
@@ -34,7 +33,6 @@ tup_object_exist . "tup varsed foo.txt out.txt"
 
 cat > Tupfile << HERE
 HERE
-tup touch Tupfile
 update
 
 tup_object_no_exist . out.txt
