@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -25,7 +25,7 @@ src-y:=
 src-@(BLAH) = foo.c
 : foreach \$(src-y) |> gcc -c %f -o %o |> %B.o
 HERE
-tup touch Tupfile foo.c
+touch foo.c
 varsetall BLAH=y
 update
 tup_object_exist . "gcc -c foo.c -o foo.o"
