@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -26,7 +26,6 @@ cat > Tupfile << HERE
 : out.txt |> cat %f > %o |> new.txt
 HERE
 echo "hey @FOO@ yo" > foo.txt
-tup touch foo.txt Tupfile
 varsetall FOO=sup
 update
 tup_object_exist . foo.txt out.txt new.txt
@@ -34,7 +33,6 @@ tup_object_exist . foo.txt out.txt new.txt
 (echo "hey sup yo") | diff new.txt -
 
 echo "a @FOO@ b" > foo.txt
-tup touch foo.txt
 update
 (echo "a sup b") | diff out.txt -
 (echo "a sup b") | diff new.txt -
