@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -24,13 +24,11 @@ cat > Tupfile << HERE
 : foo.txt |> tup varsed %f %o |> out.txt
 HERE
 echo "hey @FOO@ yo" > foo.txt
-tup touch foo.txt Tupfile
 varsetall FOO=sup
 update
 tup_object_exist . foo.txt out.txt
 echo "hey sup yo" | diff out.txt -
 
-tup touch Tupfile
 update
 
 eotup
