@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -26,7 +26,6 @@ file-@(BAR) += bar.c
 HERE
 echo hey > foo.c
 echo yo > bar.c
-tup touch foo.c bar.c Tupfile
 update
 tup_object_exist . "cat foo.c > foo.o"
 tup_object_no_exist . "cat bar.c > bar.o"
@@ -36,7 +35,6 @@ cat > Tupfile << HERE
 file-y = foo.c
 : foreach \$(file-y) |> cat %f > %o |> %B.o
 HERE
-tup touch Tupfile
 update
 
 tup_object_exist . "cat foo.c > foo.o"
