@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2010-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2010-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -29,7 +29,7 @@ files += foo.c
 files += bar.asm
 : foreach \$(files) |> !mplayer |> %B.o
 HERE
-tup touch foo.c bar.asm Tupfile
+touch foo.c bar.asm
 update
 
 check_exist foo.o bar.o
