@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2010-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2010-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -26,7 +26,7 @@ cat > Tupfile << HERE
 : foo.c |> !cc |>
 : bar.c |> !cc |> %B.newo
 HERE
-tup touch foo.c bar.c Tupfile
+touch foo.c bar.c
 update
 
 check_exist foo.o bar.newo
