@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2010-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2010-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -30,7 +30,7 @@ cat > Tupfile << HERE
 : foreach *.c |> !cc |> {objs}
 : {objs} |> !ld |> out.dll
 HERE
-tup touch Tupfile foo.c bar.c ok.sh
+touch foo.c bar.c
 update
 
 eotup
