@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -32,14 +32,14 @@ HERE
 touch bar.c
 update
 
-tup touch foo.h.in
-if ! tup upd | grep 'gcc -c' | wc -l | grep 1 > /dev/null; then
+touch foo.h.in
+if [ "$(tup | grep -c 'gcc -c')" != 1 ]; then
 	echo "Error: Expected only one file to compile" 1>&2
 	exit 1
 fi
 
-tup touch bar.h.in
-if ! tup upd | grep 'gcc -c' | wc -l | grep 0 > /dev/null; then
+touch bar.h.in
+if [ "$(tup | grep -c 'gcc -c')" != 0 ]; then
 	echo "Error: Expected no files to compile" 1>&2
 	exit 1
 fi
