@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -25,10 +25,10 @@ cat > Tupfile << HERE
 HERE
 echo '#include "foo.h"' > foo.c
 echo '#include "foo.h"' > bar.c
-tup touch foo.c bar.c foo.h
+touch foo.h
 update
 
-tup touch foo.h
+touch foo.h
 update_partial foo.o > .output.txt
 
 if grep bar.o .output.txt > /dev/null; then
