@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -20,13 +20,12 @@
 
 . ./tup.sh
 check_no_ldpreload varsed
-tmkdir sub
+mkdir sub
 cat > sub/Tupfile << HERE
 : foo.txt |> tup varsed %f %o |> out.txt
 HERE
 echo "hey @FOO@ yo" > sub/foo.txt
 echo "This is an email@address.com" >> sub/foo.txt
-tup touch sub/foo.txt sub/Tupfile
 varsetall FOO=sup
 update
 tup_object_exist sub foo.txt out.txt
