@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -22,8 +22,8 @@
 # after all files are parsed and old commands are deleted.
 . ./tup.sh
 
-tmkdir sub1
-tmkdir sub2
+mkdir sub1
+mkdir sub2
 
 cat > sub1/Tupfile << HERE
 : <foo> |> echo blah > %o |> output.txt | <bar>
@@ -35,7 +35,6 @@ HERE
 cat > sub2/Tupfile << HERE
 : <bar> |> echo blah > %o |> output.txt | <foo>
 HERE
-tup touch sub1/Tupfile sub2/Tupfile
 update
 
 eotup
