@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -20,8 +20,8 @@
 # from another directory.
 . ./tup.sh
 
-tmkdir foo
-tmkdir bar
+mkdir foo
+mkdir bar
 cat > foo/Tupfile << HERE
 : <group> |> cp ../bar/file.txt %o |> copy.txt
 HERE
@@ -33,7 +33,7 @@ update
 rm -rf foo
 tup scan
 
-tmkdir foo
+mkdir foo
 cat > foo/Tupfile << HERE
 : <group> |> cp ../bar/file.txt %o |> copy.txt
 HERE
