@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -24,9 +24,9 @@ cat > Tuprules.tup << HERE
 MY_ROOT = \$(TUP_CWD)
 HERE
 
-tmkdir foo
-tmkdir bar
-tmkdir sub
+mkdir foo
+mkdir bar
+mkdir sub
 cat > foo/Tupfile << HERE
 include_rules
 : foreach *.c |> !cc |>
