@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -20,8 +20,8 @@
 # so the group_link table is used.
 . ./tup.sh
 
-tmkdir foo
-tmkdir bar
+mkdir foo
+mkdir bar
 cat > foo/Tupfile << HERE
 : ../bar/<group> |> cp ../bar/file.txt %o |> copy.txt | ../bar/<output>
 HERE
@@ -35,7 +35,7 @@ for i in a b c; do
 	rm -rf bar
 	tup scan
 
-	tmkdir bar
+	mkdir bar
 	cat > bar/Tupfile << HERE
 : |> echo hey > %o |> file.txt | <group>
 HERE
