@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2008-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2008-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -22,17 +22,13 @@ cp ../testTupfile.tup Tupfile
 # Verify both files are compiled
 echo "int main(void) {}" > foo.c
 echo "void bar1(void) {}" > bar.c
-tup touch foo.c bar.c
 update
 sym_check foo.o main
 sym_check bar.o bar1
 
 # Verify only foo is compiled if foo.c is touched
 echo "void foo2(void) {}" >> foo.c
-tup touch foo.c
-if tup upd | grep 'gcc -c' | wc -l | grep 1 > /dev/null; then
-	:
-else
+if [ "$(tup | grep -c 'gcc -c')" != 1 ]; then
 	echo "Only foo.c should have been compiled." 1>&2
 	exit 1
 fi
@@ -40,10 +36,8 @@ sym_check foo.o main foo2
 
 # Verify both are compiled if both are touched, but only linked once
 rm foo.o
-tup touch foo.c bar.c
-if tup upd | grep 'gcc .* -o prog' | wc -l | grep 1 > /dev/null; then
-	:
-else
+touch foo.c bar.c
+if [ "$(tup | grep -c 'gcc .* -o prog')" != 1 ]; then
 	echo "Program should have only been linked once." 1>&2
 	exit 1
 fi
