@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2008-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2008-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,12 +19,10 @@
 . ./tup.sh
 cp ../testTupfile.tup Tupfile
 
-tmkdir bar
+mkdir bar
 cp ../testTupfile.tup bar/Tupfile
 echo "#define FOO 3" > foo.h
 (echo "#include \"../foo.h\""; echo "int main(void) {return FOO;}") > bar/foo.c
-tup touch foo.h
-tup touch bar/foo.c
 update
 sym_check bar/foo.o main
 tup_dep_exist . foo.h bar "gcc -c foo.c -o foo.o"
