@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -22,12 +22,12 @@ cat > Tupfile << HERE
 : fs/*.o |> ld -r %f -o built-in.o |> built-in.o
 HERE
 
-tmkdir fs
+mkdir fs
 cat > fs/Tupfile << HERE
 : foreach input/*.o |> cp %f %o |> %b
 HERE
 
-tmkdir fs/input
+mkdir fs/input
 cat > fs/input/Tupfile << HERE
 : foreach *.c |> gcc -c %f -o %o |> %B.o
 HERE
@@ -35,13 +35,11 @@ HERE
 echo "void ext3fs(void) {}" > fs/input/ext3.c
 echo "void ext4fs(void) {}" > fs/input/ext4.c
 
-tup touch Tupfile fs/Tupfile fs/input/Tupfile fs/input/ext3.c fs/input/ext4.c
 update
 
 sym_check built-in.o ext3fs ext4fs
 
 echo "void ext5fs(void) {}" > fs/input/ext5.c
-tup touch fs/input/ext5.c
 update
 sym_check built-in.o ext3fs ext4fs ext5fs
 
