@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -21,12 +21,12 @@
 # the link is removed.
 . ./tup.sh
 
-tmkdir bar
+mkdir bar
 cat > bar/Tupfile << HERE
 : ../fs/*.o |> ld -r %f -o built-in.o |> built-in.o
 HERE
 
-tmkdir fs
+mkdir fs
 cat > fs/Tupfile << HERE
 : foreach *.c |> gcc -c %f -o %o |> %B.o
 HERE
@@ -34,7 +34,6 @@ HERE
 echo "void ext3fs(void) {}" > fs/ext3.c
 echo "void ext4fs(void) {}" > fs/ext4.c
 
-tup touch bar/Tupfile fs/Tupfile fs/ext3.c fs/ext4.c
 update
 
 tup_dep_exist . fs . bar
@@ -42,7 +41,6 @@ sym_check bar/built-in.o ext3fs ext4fs
 
 cat > bar/Tupfile << HERE
 HERE
-tup touch bar/Tupfile
 update
 tup_dep_no_exist . fs . bar
 check_not_exist bar/built-in.o
