@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -27,7 +27,6 @@ cat > Tupfile << HERE
 HERE
 
 echo "int main(void) {}" > foo.c
-tup touch foo.c Tupfile
 update
 check_exist foo.o
 
@@ -35,7 +34,6 @@ cat > Tupfile << HERE
 : foreach *.c |> echo gcc -c %f -o %o |> %B.o
 HERE
 
-tup touch Tupfile
 update_fail_msg "Expected to write to file 'foo.o'"
 
 eotup
