@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -24,7 +24,7 @@ mkdir tmp
 cd tmp
 re_init
 
-tmkdir sub
+mkdir sub
 cd sub
 cat > ok.sh << HERE
 #! /bin/sh
@@ -42,7 +42,6 @@ HERE
 
 echo "yo" > bar
 
-tup touch bar Tupfile ok.sh
 update
 
 tup_dep_exist sub bar sub './ok.sh'
