@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -20,11 +20,11 @@
 
 . ./tup.sh
 
-tmkdir sub
-tmkdir sub/dir
+mkdir sub
+mkdir sub/dir
 cd sub/dir
 
-tmkdir tmp
+mkdir tmp
 cat > ok.sh << HERE
 #! /bin/sh
 cd tmp
@@ -39,7 +39,6 @@ HERE
 echo "yo" > tmp/bar
 echo "not this one" > bar
 
-tup touch bar tmp/bar Tupfile ok.sh
 update
 
 tup_dep_exist sub/dir/tmp bar sub/dir './ok.sh'
