@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -36,7 +36,7 @@ cat > Tupfile << HERE
 : foo.c |> gcc %f -o %o |> foo.exe
 : foo.exe |> ./%f |>
 HERE
-tup touch foo.c Tupfile access.txt
+touch access.txt
 update
 
 tup_dep_exist . access.txt . "./foo.exe"
