@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -25,15 +25,13 @@ check_no_ldpreload mozilla-unneeded
 cat > Tupfile << HERE
 : |> mkdir %o |> outdir
 HERE
-tup touch Tupfile
 update_fail_msg "tup error.*outdir"
 
-tmkdir outdir
+mkdir outdir
 
 cat > Tupfile << HERE
 : |> rmdir outdir |>
 HERE
-tup touch Tupfile
 update_fail_msg "tup error.*rmdir"
 
 eotup
