@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -27,7 +27,7 @@ check_no_ldpreload mozilla-unneeded
 cat > Tupfile << HERE
 : tmp |> link %f %o |> outlink
 HERE
-tup touch tmp Tupfile
+touch tmp
 update_fail_msg "tup error.*hard links"
 
 eotup
