@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -25,13 +25,12 @@ check_no_ldpreload mozilla-unneeded
 cat > Tupfile << HERE
 : |> touch %o; chmod 664 %o |> test1
 HERE
-tup touch Tupfile
 update
 
 cat > Tupfile << HERE
 : |> chmod 664 test2 |>
 HERE
-tup touch Tupfile test2
+touch test2
 update_fail_msg "tup error.*chmod"
 
 eotup
