@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,13 +23,12 @@
 cat > Tupfile << HERE
 : |> echo hey > %o; touch -t 202005080000 %o |> foo
 HERE
-tup touch Tupfile
 update
 
 cat > Tupfile << HERE
 : |> touch -t 202005080000 test2 |>
 HERE
-tup touch Tupfile test2
+touch test2
 # Windows fails with 'Unspecified output files'
 update_fail_msg "\(tup error.*utimens\|Unspecified output files\)"
 
