@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -46,7 +46,7 @@ cat > Tupfile << HERE
 : ok.c |> gcc %f -o %o |> ok
 : ok |> ./%f |>
 HERE
-tup touch ok.c foo.txt Tupfile
+touch foo.txt
 update
 
 tup_dep_exist . foo.txt . ./ok
