@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -24,8 +24,7 @@ cat > Tupfile << HERE
 : *.txt |> ^ Misty cat^ cat %f > %o |> output.txt
 HERE
 filelist=`seq 1 2000 | awk '{print "hey"$1".txt"}'`
-tup touch $filelist
-tup touch Tupfile
+touch $filelist
 update
 
 eotup
