@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -24,7 +24,7 @@ tmp=".tmp.txt"
 cat > Tupfile << HERE
 : ok.c |> ^ short^ gcc -c %f -o %o |> %B.o
 HERE
-tup touch ok.c Tupfile
+touch ok.c
 update > $tmp
 
 if ! grep short $tmp > /dev/null; then
@@ -36,7 +36,7 @@ if grep 'gcc -c ok.c -o ok.o' $tmp > /dev/null; then
 	exit 1
 fi
 
-tup touch ok.c
+touch ok.c
 update --verbose > $tmp
 if grep short $tmp > /dev/null; then
 	echo "Error: Expected 'short' not to be in the output text." 1>&2
