@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2011-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2011-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -24,9 +24,9 @@ cat > Tupfile << HERE
 : foo.c |> gcc -c %f -o %o |> %B.o
 HERE
 
-tmkdir sub
+mkdir sub
 
-tup touch foo.c Tupfile
+touch foo.c
 update
 
 check_exist foo.o
