@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2010-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2010-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,14 +23,13 @@ cp ../testTupfile.tup Tupfile
 
 echo "int main(void) {}" > foo.c
 echo "void bar1(void) {}" > bar.c
-tup touch foo.c bar.c
 update
 
-tup touch Tupfile
+touch Tupfile
 tup todo | grep 'Tup phase 2'
 parse
 
-tup touch foo.c
+touch foo.c
 tup todo | grep 'Tup phase 3.* 2 commands'
 tup upd
 
