@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -25,7 +25,6 @@ set_full_deps
 cp ../testTupfile.tup Tupfile
 
 echo "int main(void) {}" > foo.c
-tup touch foo.c
 update
 sym_check foo.o main
 
@@ -45,7 +44,6 @@ esac
 tup_object_exist $path $filename
 
 rm Tupfile
-tup rm Tupfile
 update
 tup_object_no_exist $path $filename
 
