@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -38,20 +38,20 @@ esac
 cat > Tupfile << HERE
 : foreach *.c |> gcc -c %f -o %o |> %B.o
 HERE
-tup touch Tupfile foo.c bar.c
+touch foo.c bar.c
 update
 
 tup_object_no_exist $path $filename
 
 set_full_deps
-if ! tup upd | grep 'gcc -c' | wc -l | grep 2 > /dev/null; then
+if [ "$(tup | grep -c 'gcc -c')" != 2 ]; then
 	echo "Error: All files should have been recompiled when updater.full_deps was set." 1>&2
 	exit 1
 fi
 tup_object_exist $path $filename
 
 clear_full_deps
-if ! tup upd | grep 'gcc -c' | wc -l | grep 0 > /dev/null; then
+if [ "$(tup | grep -c 'gcc -c')" != 0 ]; then
 	echo "Error: No files should have been recompiled when updater.full_deps was cleared." 1>&2
 	exit 1
 fi
