@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -38,7 +38,7 @@ int main(int argc, char **argv)
 }
 HERE
 
-tup touch foo.c Tupfile
+touch foo.c Tupfile
 update_fail_msg "tup error: This process requires namespacing, but this kernel does not support namespacing and tup is not privileged."
 
 eotup
