@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,16 +23,14 @@
 cat > Tupfile << HERE
 : |> touch bar |> bar
 HERE
-tup touch Tupfile
 update
 
-tup touch Tupfile
+touch Tupfile
 refactor
 
 cat > Tupfile << HERE
 : |> touch bar |>
 HERE
-tup touch Tupfile
 refactor_fail_msg "Attempting to remove an output from a command: bar"
 
 eotup
