@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -24,12 +24,11 @@ cat > Tupfile << HERE
 .gitignore
 : |> touch %o |> foo
 HERE
-tup touch Tupfile
 update
 
 gitignore_good foo .gitignore
 
-tup touch Tupfile
+touch Tupfile
 refactor
 
 gitignore_good foo .gitignore
