@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -21,24 +21,22 @@
 
 . ./tup.sh
 
-tmkdir foo
+mkdir foo
 cat > foo/Tupfile << HERE
 .gitignore
 : |> echo foo > %o |> baz.txt
 HERE
-tup touch foo/Tupfile
 update
 
 cat > Tupfile << HERE
 : |> echo hey > %o |> foo/bar.txt
 HERE
-tup touch Tupfile
 update
 
 gitignore_good baz.txt foo/.gitignore
 gitignore_good bar.txt foo/.gitignore
 
-if ! cat foo/.gitignore | grep '\.gitignore' | wc -l | grep 1 > /dev/null; then
+if [ "$(grep -c '\.gitignore' foo/.gitignore)" != 1 ]; then
 	echo "Error: Expected only one .gitignore line in the .gitignore file." 1>&2
 	exit 1
 fi
