@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -22,8 +22,8 @@
 
 . ./tup.sh
 
-tmkdir foo
-tmkdir bar
+mkdir foo
+mkdir bar
 cat > foo/Tupfile << HERE
 : foreach *.c |> gcc -c %f -o %o |> %B.o
 : *.o |> ar cr %o %f |> libfoo.a
@@ -34,12 +34,11 @@ HERE
 echo "int marfx;" > foo/x.c
 echo "int marfy;" > foo/y.c
 echo "int marfz;" > bar/z.c
-tup touch foo/Tupfile bar/Tupfile
 update
 
 sym_check foo/libfoo.a marfx marfy ^marfz
 
-tup touch foo/Tupfile
+touch foo/Tupfile
 update
 
 sym_check foo/libfoo.a marfx marfy ^marfz
