@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -21,11 +21,10 @@
 
 . ./tup.sh
 
-tmkdir foo
+mkdir foo
 cat > Tupfile << HERE
 : |> touch %o |> foo/ok.txt
 HERE
-tup touch Tupfile
 update
 
 tup_object_exist foo ok.txt
@@ -33,7 +32,6 @@ check_exist foo/ok.txt
 
 cat > Tupfile << HERE
 HERE
-tup touch Tupfile
 update
 
 tup_object_no_exist foo ok.txt
