@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -26,12 +26,12 @@ cat > Tupfile << HERE
 HERE
 update
 
-tmkdir foo
+mkdir foo
 cat > foo/Tupfile << HERE
 .gitignore
 : foreach *.c |> gcc -c %f -o %o |> ../sub/sub2/%B.o
 HERE
-tup touch foo/foo.c foo/bar.c
+touch foo/foo.c foo/bar.c
 update
 
 gitignore_good sub .gitignore
