@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -21,7 +21,7 @@
 
 . ./tup.sh
 
-tmkdir foo
+mkdir foo
 cat > ok.sh << HERE
 if [ -f foo/ok.txt ]; then echo yes; else echo no; fi
 HERE
@@ -29,7 +29,7 @@ cat > Tupfile << HERE
 : |> echo hey > %o |> foo/bar/new/baz.txt <txt>
 : |> sh ok.sh |>
 HERE
-tmkdir sub
+mkdir sub
 cat > sub/Tupfile << HERE
 : ../<txt> |> cat ../foo/bar/new/baz.txt |>
 HERE
