@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -20,8 +20,8 @@
 
 . ./tup.sh
 
-tmkdir foo
-tup touch foo/ok.txt
+mkdir foo
+touch foo/ok.txt
 cat > Tupfile << HERE
 : |> touch %o |> foo/bar.txt
 HERE
