@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,12 +19,12 @@
 # Try tup graph . both with and without --dirs
 . ./tup.sh
 
-tmkdir sub
+mkdir sub
 cat > sub/Tupfile << HERE
 .gitignore
 : in.txt |> cp %f %o |> out.txt
 HERE
-tup touch sub/Tupfile sub/in.txt
+touch sub/in.txt
 update
 
 tup graph . > ok.dot
