@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -26,7 +26,7 @@ HERE
 update
 
 rm -rf foo/bar
-tup touch foo/bar
+touch foo/bar
 # foo.bar.baz uses the . as a wildcard for matching Windows & Unix paths
 update_fail_msg "Unable to output to a different directory because 'foo.bar' is a normal file"
 
