@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -20,8 +20,8 @@
 
 . ./tup.sh
 
-tmkdir sub
-tmkdir sub/dir
+mkdir sub
+mkdir sub/dir
 cat > sub/dir/ok.sh << HERE
 echo stringa > a
 echo stringb > b
@@ -45,7 +45,6 @@ echo stringa > a
 echo stringb > b
 echo cstring > c
 HERE
-tup touch sub/dir/ok.sh
 update > .output.txt
 
 gitignore_bad stringa .output.txt
