@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -27,7 +27,7 @@ cleanup()
 	rm -rf $tmpdir
 }
 
-trap cleanup INT TERM
+trap cleanup EXIT INT TERM
 cleanup
 mkdir $tmpdir
 cd $tmpdir
@@ -36,11 +36,7 @@ tup 2> $output || true
 
 if ! grep 'No .tup directory found' $output > /dev/null; then
 	echo "Error: Expected tup to print an error message." 1>&2
-	cleanup
 	exit 1
 fi
 
-cleanup
-
-cd $tupcurdir
 eotup
