@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2008-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2008-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,7 +23,7 @@ cat > Tupfile << HERE
 !foo = |> cat -v |>
 : foreach *.c |> !foo "%f" > "%o" |> bin/%B
 HERE
-tup touch foo.c
+touch foo.c
 update
 
 tup_object_exist . 'cat -v "foo.c" > "bin/foo"'
