@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2016-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2016-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -22,14 +22,14 @@
 cat > Tupfile << HERE
 : foreach	file.c |> gcc -c %f -o %o |> %B.o
 HERE
-tup touch Tupfile file.c
+touch file.c
 update
 
 cat > Tupfile << HERE
 !cc = foreach	| blah.h |> gcc -c %f -o %o |> %B.o
 : foo.c |> !cc |>
 HERE
-tup touch Tupfile foo.c blah.h
+touch foo.c blah.h
 update
 
 eotup
