@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2018-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2018-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -26,7 +26,7 @@ HERE
 
 echo "int main(void) {}" > foo.c
 echo '#include "bar.h"' > bar.c
-tup touch foo.c bar.c bar.h
+touch bar.h
 update
 
 tup_dep_exist . bar.h . 'clang -c bar.c -o bar.o'
