@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2018-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2018-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -44,8 +44,8 @@ cat > Tupfile << HERE
 : |> gcc prog.c -o %o |> prog.exe
 : prog.exe |> ./prog.exe |> output.txt sub/subout.txt
 HERE
-tmkdir sub
-tup touch input.txt sub/subin.txt Tupfile
+mkdir sub
+touch input.txt sub/subin.txt
 update
 
 tup_dep_exist . input.txt . './prog.exe'
