@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2020-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2020-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -25,12 +25,10 @@
 cat > Tupfile << HERE
 : |> echo generated > %o |> sub/genfile.txt
 HERE
-tup touch Tupfile
 update
 
 rm Tupfile
 echo 'manual' > sub/genfile.txt
-tup touch sub/genfile.txt
 update
 
 if ! tup type sub | grep '^directory'; then
