@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2008-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2008-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,7 +23,6 @@ cp ../testTupfile.tup Tupfile
 echo "int main(void) {return 0;}" > foo.c
 echo "void bar1(void) {}" > bar.c
 echo "void baz1(void) {}" > baz.c
-tup touch foo.c bar.c baz.c
 update
 sym_check foo.o main
 sym_check bar.o bar1
@@ -33,7 +32,6 @@ sym_check prog.exe main bar1 baz1
 # When baz.c is deleted, baz.o should be deleted as well, and prog.exe should be
 # re-linked. The baz.[co] objects should be removed from .tup
 rm baz.c
-tup rm baz.c
 update
 check_not_exist baz.o
 sym_check prog.exe main bar1 ^baz1
@@ -42,7 +40,6 @@ tup_object_exist . foo.c foo.o bar.c bar.o prog.exe
 tup_object_no_exist . baz.c baz.o
 
 rm foo.c bar.c
-tup rm foo.c bar.c
 update
 check_not_exist foo.o bar.o prog.exe
 tup_object_no_exist . foo.c foo.o bar.c bar.o prog.exe
