@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2008-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2008-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -22,7 +22,6 @@ cp ../testTupfile.tup Tupfile
 # Verify both files are compiled
 echo "int main(void) {return 0;}" > foo.c
 echo "void bar1(void) {}" > bar.c
-tup touch foo.c bar.c
 update
 sym_check foo.o main
 sym_check bar.o bar1
@@ -30,8 +29,6 @@ sym_check prog.exe main bar1
 
 # Rename bar.c to realbar.c.
 mv bar.c realbar.c
-tup rm bar.c
-tup touch realbar.c
 update
 check_not_exist bar.o
 tup_object_no_exist bar.c bar.o
