@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -17,11 +17,10 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 . ./tup.sh
-tmkdir a
+mkdir a
 cp ../testTupfile.tup a/Tupfile
 
 echo "int main(void) {return 0;}" > a/foo.c
-tup touch a/foo.c a/Tupfile
 update
 tup_object_exist . a
 tup_object_exist a foo.c foo.o prog.exe
@@ -30,10 +29,9 @@ sym_check a/prog.exe main
 
 # Move directory a to b
 mv a b
-tup rm a
-tup touch b b/foo.c b/Tupfile
-# TODO: instead of --no-scan, use --overwrite-outputs or some such
-update --no-scan
+# TODO: instead of removing files, use --overwrite-outputs or some such
+rm b/foo.o b/prog.exe
+update
 tup_object_exist . b
 tup_object_exist b foo.c foo.o prog.exe
 tup_object_no_exist . a
