@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -17,12 +17,11 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 . ./tup.sh
-tmkdir a
-tmkdir a/a2
+mkdir a
+mkdir a/a2
 cp ../testTupfile.tup a/a2/Tupfile
 
 echo "int main(void) {return 0;}" > a/a2/foo.c
-tup touch a/a2/foo.c a/a2/Tupfile
 update
 tup_object_exist . a
 tup_object_exist a a2
@@ -32,10 +31,9 @@ sym_check a/a2/prog.exe main
 
 # Move directory a to b
 mv a b
-tup rm a
-tup touch b b/a2 b/a2/foo.c b/a2/Tupfile
 # TODO: replace with --overwrite-outputs
-update --no-scan
+rm b/a2/foo.o b/a2/prog.exe
+update
 tup_object_exist . b
 tup_object_exist b a2
 tup_object_exist b/a2 foo.c foo.o prog.exe 'gcc -c foo.c -o foo.o' 'gcc foo.o -o prog.exe'
