@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -17,12 +17,11 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 . ./tup.sh
-tmkdir a
-tmkdir a/a2
+mkdir a
+mkdir a/a2
 cp ../testTupfile.tup a/a2/Tupfile
 
 echo "int main(void) {return 0;}" > a/a2/foo.c
-tup touch a/a2/foo.c a/a2/Tupfile
 update
 tup_object_exist . a
 tup_object_exist a a2
@@ -31,7 +30,6 @@ sym_check a/a2/foo.o main
 sym_check a/a2/prog.exe main
 
 rm -rf a
-tup rm a
 update
 tup_object_no_exist . a
 tup_object_no_exist a a2
