@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -22,13 +22,11 @@ echo 'this is a file' > file1
 cat > Tupfile << HERE
 : file1 |> ln -s %f %o |> file1.sym
 HERE
-tup touch file1 Tupfile
 update
 
 check_exist file1.sym
 cat > Tupfile << HERE
 HERE
-tup touch Tupfile
 update
 check_not_exist file1.sym
 
