@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -24,14 +24,11 @@ cat > Tupfile << HERE
 HERE
 
 echo 'foo' > .hidden
-tmkdir yo
+mkdir yo
 mkdir yo/.hidden_dir
-tup touch yo/.hidden_dir
+touch yo/.hidden_dir
 echo 'bar' > yo/.hidden_dir/foo
 
-tup touch .hidden
-tup touch yo/.hidden_dir/foo
-tup touch Tupfile
 update
 tup_object_exist . .hidden
 tup_object_exist . 'cat .hidden'
