@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -21,7 +21,7 @@
 . ./tup.sh
 check_no_windows symlink
 
-tmkdir arch
+mkdir arch
 echo "#define FOO 3" > arch/foo-x86.h
 echo "#define FOO 4" > arch/foo-ppc.h
 ln -s arch/foo-x86.h foo.h
@@ -29,7 +29,6 @@ echo '#include "foo.h"' > foo.c
 cat > Tupfile << HERE
 : foreach *.c |> gcc -c %f -o %o |> %B.o
 HERE
-tup touch foo.c arch/foo-x86.h arch/foo-ppc.h foo.h
 update
 check_exist foo.o
 
@@ -38,7 +37,6 @@ check_updates arch/foo-x86.h foo.o
 check_no_updates arch/foo-ppc.h foo.o
 
 ln -sf arch/foo-ppc.h foo.h
-tup touch foo.h
 update
 check_updates foo.h foo.o
 check_no_updates arch/foo-x86.h foo.o
