@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,7 +23,6 @@ check_no_windows symlink
 check_no_ldpreload symlink-dir
 mkdir arch-x86
 mkdir arch-ppc
-tup touch arch-x86 arch-ppc
 echo "#define FOO 3" > arch-x86/foo.h
 echo "#define FOO 4" > arch-ppc/foo.h
 ln -s arch-x86 arch
@@ -31,7 +30,6 @@ echo '#include "arch/foo.h"' > foo.c
 cat > Tupfile << HERE
 : foreach *.c |> gcc -c %f -o %o |> %B.o
 HERE
-tup touch Tupfile foo.c arch-x86/foo.h arch-ppc/foo.h arch
 update
 check_exist foo.o
 
@@ -40,7 +38,6 @@ check_no_updates arch-ppc/foo.h foo.o
 
 rm -f arch
 ln -sf arch-ppc arch
-tup touch arch
 update
 check_no_updates arch-x86/foo.h foo.o
 check_updates arch-ppc/foo.h foo.o
