@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,19 +23,17 @@
 . ./tup.sh
 check_no_windows symlink
 
-tmkdir foo
-tmkdir foo/arch-x86
+mkdir foo
+mkdir foo/arch-x86
 echo 'var = 3' > foo/arch-x86/rules.tup
 cat > foo/Tupfile << HERE
 : arch-x86 |> ln -s %f %o |> arch
 HERE
-tup touch foo/arch-x86/rules.tup foo/Tupfile
 update
 
 cat > Tupfile << HERE
 include foo/arch/rules.tup
 HERE
-tup touch Tupfile
 update_fail
 
 eotup
