@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -26,21 +26,18 @@ ln -s foo-x86.h foo.h
 cat > Tupfile << HERE
 : foo.h |> (cat %f 2>/dev/null || echo 'nofile') > %o |> output.txt
 HERE
-tup touch foo-x86.h foo.h
 update
 echo '#define FOO 3' | diff - output.txt
 check_updates foo.h output.txt
 check_updates foo-x86.h output.txt
 
 rm -f foo-x86.h
-tup rm foo-x86.h
 update
 echo 'nofile' | diff - output.txt
 # Careful: Can't do check_updates with foo.h here since the touch() will end
 # up changing the sym field of foo.h
 
 echo "#define FOO new" > foo-x86.h
-tup touch foo-x86.h
 update
 echo '#define FOO new' | diff - output.txt
 check_updates foo.h output.txt
