@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -24,12 +24,10 @@ cat > Tupfile << HERE
 : |> ln -s secret/ghost %o |> foo
 : foo |> cat %f 2>/dev/null || true |>
 HERE
-tup touch Tupfile
 update
 tup_object_exist . foo secret
 
 rm -f Tupfile
-tup rm Tupfile
 update
 tup_object_no_exist secret ghost
 tup_object_no_exist . foo secret
