@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -22,21 +22,16 @@ check_no_windows shell
 
 ln -s a b
 ln -s b a
-tup touch a
-tup touch b
 cat > Tupfile << HERE
 : |> if [ -f a ]; then cat a 2>/dev/null; else echo yo; fi > %o |> output.txt
 HERE
-tup touch Tupfile
 update
 echo yo | diff - output.txt
 
 cat > Tupfile << HERE
 : |> echo yoi > %o |> output.txt
 HERE
-tup touch Tupfile
 rm -f a b
-tup rm a b
 update
 echo yoi | diff - output.txt
 tup_object_no_exist . a b
