@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -22,10 +22,10 @@
 cat > Tupfile << HERE
 : |> cat input.txt > .hidden |> .hidden
 HERE
-tup touch Tupfile input.txt
+touch input.txt
 update
 
-tup touch input.txt
+touch input.txt
 update
 
 eotup
