@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -20,12 +20,11 @@
 
 . ./tup.sh
 check_no_windows shell
-tmkdir foo
-tmkdir include
+mkdir foo
+mkdir include
 cat > foo/Tupfile << HERE
 : |> if [ -f ../include/../../../../../../../bar/lg.h ]; then echo yay; else echo no; fi |>
 HERE
-tup touch foo/Tupfile
 update
 
 eotup
