@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -20,17 +20,15 @@
 # that it's in.
 
 . ./tup.sh
-tmkdir foo
+mkdir foo
 cat > Tupfile << HERE
 : |> (cat foo/ghost 2>/dev/null || echo nofile) > %o |> output.txt
 HERE
-tup touch Tupfile
 update
 echo nofile | diff - output.txt
 
 cat > Tupfile << HERE
 HERE
-tup touch Tupfile
 update
 
 tup_object_exist . foo
