@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,11 +19,10 @@
 # Like t5038, but in a subdirectory.
 . ./tup.sh
 
-tmkdir sub
+mkdir sub
 cat > sub/Tupfile << HERE
 : |> touch foo; touch bar |> foo
 HERE
-tup touch sub/Tupfile
 update_fail
 
 check_not_exist sub/bar
@@ -31,7 +30,6 @@ check_not_exist sub/bar
 cat > sub/Tupfile << HERE
 : |> touch foo |> foo
 HERE
-tup touch sub/Tupfile
 update
 
 check_exist sub/foo
