@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -21,8 +21,8 @@
 # there).
 . ./tup.sh
 
-tmkdir foo
-tmkdir bar
+mkdir foo
+mkdir bar
 echo '#define FOO 3' > foo/me.h
 echo '#define FOO 5' > bar/me.h
 echo '#include "me.h"' > ok.c
@@ -30,14 +30,12 @@ echo '#include "me.h"' > ok.c
 cat > Tupfile << HERE
 : ok.c |> gcc -c %f -o %o -Ifoo -Ibar |> ok.o
 HERE
-tup touch foo/me.h bar/me.h ok.c Tupfile
 update
 
 tup_dep_exist foo me.h . 'gcc -c ok.c -o ok.o -Ifoo -Ibar'
 tup_dep_no_exist bar me.h . 'gcc -c ok.c -o ok.o -Ifoo -Ibar'
 
 rm foo/me.h
-tup rm foo/me.h
 update
 
 tup_dep_exist foo me.h . 'gcc -c ok.c -o ok.o -Ifoo -Ibar'
