@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,18 +23,16 @@
 mkdir real
 cd real
 re_init
-tmkdir sub
+mkdir sub
 echo "#define FOO 3" > sub/foo.h
 echo '#include "foo.h"' > foo.c
 echo ': foreach *.c |> gcc -c %f -o %o -Isub |> %B.o' > Tupfile
-tup touch Tupfile foo.c sub/foo.h
 update
 
 mv sub ..
-tup rm sub
 update_fail
 
-tup touch foo.h
+touch foo.h
 update
 
 eotup
