@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,14 +23,12 @@
 mkdir real
 cd real
 re_init
-tmkdir sub
+mkdir sub
 echo ': |> echo blah |>' > sub/Test.tup
 echo 'include sub/Test.tup' > Tupfile
-tup touch Tupfile sub/Test.tup
 update
 
 mv sub ..
-tup rm sub
 update_fail
 
 eotup
