@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,21 +19,23 @@
 # Like t5013, but now with execv (at least gcc uses execv).
 
 . ./tup.sh
+
+# After updating cygwin, apparently the execl causes the WaitForSingleObject()
+# call to return immediately, even though prog.exe is still running and
+# has the .tup/tmp/output-%i file open.
+check_no_windows execl
+
 cat > Tupfile << HERE
 : foreach exec_test.c prog.c |> gcc %f -o %o |> %B.exe
 : exec_test.exe prog.exe |> ./exec_test.exe && touch %o |> test_passed
 HERE
-const=""
-if [ "$in_windows" = "1" ]; then
-	const="const"
-fi
 cat > exec_test.c << HERE
 #include <stdio.h>
 #include <unistd.h>
 
 int main(void)
 {
-	$const char * const args[] = {"prog.exe", NULL};
+	char * const args[] = {"prog.exe", NULL};
 	execv("./prog.exe", args);
 	return 1;
 }
@@ -41,7 +43,6 @@ HERE
 cat > prog.c << HERE
 int main(void) {return 0;}
 HERE
-tup touch Tupfile exec_test.c prog.c
 update
 
 check_updates prog.c test_passed
