@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -35,7 +35,7 @@ mkdir bar
 echo 'hey' > bar/ghost
 rm boo
 ln -s bar boo
-tup touch boo
+touch boo
 update
 echo 'hey' | diff - out.txt
 
