@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,11 +19,11 @@
 # Like t5038, but the file is written in a different directory
 . ./tup.sh
 
-tmkdir sub
+mkdir sub
 cat > Tupfile << HERE
 : |> touch foo; touch sub/bar |> foo
 HERE
-tup touch bar Tupfile
+touch bar
 update_fail
 
 check_exist bar
@@ -32,7 +32,6 @@ check_not_exist sub/bar
 cat > Tupfile << HERE
 : |> touch foo |> foo
 HERE
-tup touch Tupfile
 update
 
 check_exist foo bar
