@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -27,12 +27,10 @@ cat > Tupfile << HERE
 HERE
 echo "void foo(void) {}" > foo.c
 echo "void bar(void) {}" > bar.c
-tup touch foo.c bar.c Tupfile
 update
 sym_check lib.a foo bar
 
 rm foo.c
-tup rm foo.c
 update
 sym_check lib.a ^foo bar
 
