@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2010-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2010-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -43,12 +43,10 @@ cat > Tupfile << HERE
 : ok.c |> gcc %f -o %o |> tup_t5067_segfault2
 : tup_t5067_segfault2 |> ./%f |> tmp.txt
 HERE
-tup touch ok.c Tupfile
 update_fail_msg "Segmentation fault"
 
 cat > Tupfile << HERE
 HERE
-tup touch Tupfile
 update
 check_not_exist tmp.txt tup_t5067_segfault2
 
