@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -20,20 +20,19 @@
 # initial compilation.
 . ./tup.sh
 
-tmkdir b
+mkdir b
 echo 'int x;' > b/foo.h
 echo '#include "foo.h"' > ok.c
 
 cat > Tupfile << HERE
 : ok.c |> gcc -c %f -o %o -Ia -Ib |> ok.o
 HERE
-tup touch b/foo.h ok.c Tupfile
 update
 
 tup_dep_exist b foo.h . 'gcc -c ok.c -o ok.o -Ia -Ib'
 sym_check ok.o x
 
-tmkdir a
+mkdir a
 echo 'int y;' > a/foo.h
 update
 
