@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -25,7 +25,7 @@ cat > Tupfile << HERE
 : foo/*.o |> gcc %f -o %o |> prog
 HERE
 
-tmkdir foo
+mkdir foo
 cat > foo/Tupfile << HERE
 : foreach ../*.c |> gcc -c %f -o %o |> %B.o
 HERE
@@ -34,7 +34,6 @@ cat > foo/ok.c << HERE
 int main(void) {return 0;}
 HERE
 
-tup touch Tupfile foo/Tupfile foo/ok.c
 update_fail
 
 eotup
