@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -33,7 +33,6 @@ cat > foo.c << HERE
 #include "foo.h"
 int main(void) {return FOO;}
 HERE
-tup touch foo.c foo.h.in Tupfile
 update
 
 cat > Tupfile << HERE
@@ -42,7 +41,6 @@ HERE
 cat > foo.c << HERE
 int main(void) {return 7;}
 HERE
-tup touch Tupfile foo.c
 update
 
 eotup
