@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -28,7 +28,7 @@ re_init
 cat > Tupfile << HERE
 : |> gcc -c foo.c |> foo.o
 HERE
-tup touch Tupfile foo.c
+touch foo.c
 update
 
 check_exist foo.o
