@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -25,9 +25,6 @@ touch foo/foo.h
 
 update
 
-# Use a sleep here to force a scan, since calling 'tup rm' and 'tup touch' already
-# works.
-sleep 1
 rm -rf foo
 touch foo
 update
