@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,7 +23,7 @@
 cat > Tupfile << HERE
 : foreach foo.c |> gcc -c %f -o %o |> %o
 HERE
-tup touch foo.c Tupfile
+touch foo.c
 update_fail_msg "%o can only be used in a command string"
 
 eotup
