@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2018-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2018-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -28,8 +28,7 @@ update
 cat > Tupfile << HERE
 : |> touch %o |> foo.txt <output-group>
 HERE
-tup touch output.txt
-tup touch Tupfile
+touch output.txt
 update --debug-logging
 
 tup_dep_no_exist . 'output.txt' . '<output-group>'
