@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2018-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2018-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -27,8 +27,7 @@ cat > Tupfile << HERE
 : |> cat sub/foo 2>/dev/null || true; touch bar |> bar
 : bar |> cat bar 2>/dev/null; touch sub |>
 HERE
-tup touch sub
-tup touch Tupfile
+touch sub
 update_fail_msg "Unspecified output files"
 
 cat > Tupfile << HERE
@@ -38,7 +37,6 @@ HERE
 rm -rf sub
 mkdir sub
 touch sub/unused
-tup touch Tupfile
 update_fail_msg "Attempting to insert 'sub' as a generated node"
 
 eotup
