@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2020-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2020-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -24,14 +24,13 @@ cat > Tupfile << HERE
 : |> touch %o |> baz.c
 : foreach *.c |> gcc -c %f -o %o |> %B.o
 HERE
-tup touch Tupfile foo.c bar.c
+touch foo.c bar.c
 update
 
 cat > Tupfile << HERE
 : foreach *.c |> gcc -c %f -o %o |> %B.o
 HERE
 echo 'int x;' > baz.c
-tup touch Tupfile baz.c
 update
 
 check_exist foo.o bar.o baz.o
