@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -47,9 +47,7 @@ esac
 tup_dep_exist $path $filename . 'gcc -c foo.c -o foo.o'
 
 tup fake_mtime $path$filename 5
-if tup upd | grep 'gcc -c' | wc -l | grep 1 > /dev/null; then
-	:
-else
+if [ "$(tup | grep -c 'gcc -c')" != 1 ]; then
 	echo "Changing timestamp on /usr/bin/gcc should have caused foo.c to re-compile." 1>&2
 	exit 1
 fi
