@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -18,10 +18,9 @@
 
 # Try rm -rf'ing a variant directory.
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build
-tmkdir build-debug
+mkdir build
+mkdir build-debug
 
 cat > Tupfile << HERE
 ifeq (@(DEBUG),y)
@@ -31,7 +30,6 @@ endif
 HERE
 echo "CONFIG_DEBUG=y" > build-debug/tup.config
 echo "" > build/tup.config
-tup touch build/tup.config build-debug/tup.config Tupfile
 
 update
 check_exist build/bar
