@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -18,10 +18,9 @@
 
 # Make sure we can create a new variant.
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build
-tmkdir sub
+mkdir build
+mkdir sub
 
 cat > sub/Tupfile << HERE
 ifeq (@(DEBUG),y)
@@ -30,7 +29,6 @@ endif
 : |> touch %o |> bar
 HERE
 echo "" > build/tup.config
-tup touch build/tup.config sub/Tupfile
 
 update
 check_exist build/sub/bar
@@ -39,9 +37,8 @@ check_not_exist build-debug
 
 update
 
-tmkdir build-debug
+mkdir build-debug
 echo "CONFIG_DEBUG=y" > build-debug/tup.config
-tup touch build-debug/tup.config
 update
 check_exist build-debug/sub/bar
 check_exist build-debug/sub/foo
