@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -18,25 +18,22 @@
 
 # Make sure a new src directory gets propagated to all variants.
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build
-tmkdir build-debug
+mkdir build
+mkdir build-debug
 
 echo "" > build/tup.config
 echo "CONFIG_DEBUG=y" > build-debug/tup.config
-tup touch build/tup.config build-debug/tup.config
 
 update
 
-tmkdir sub
+mkdir sub
 cat > sub/Tupfile << HERE
 ifeq (@(DEBUG),y)
 : |> touch %o |> foo
 endif
 : |> touch %o |> bar
 HERE
-tup touch sub/Tupfile
 update
 
 check_exist build/sub/bar
