@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,22 +19,21 @@
 # Make sure if we have a dir in the variant that is a ghost, we can still
 # create that directory in the src tree and have it work.
 . ./tup.sh
-check_no_windows variant
+check_no_windows shell
 
-tmkdir build
+mkdir build
 
 echo "" > build/tup.config
 
-tmkdir sub
+mkdir sub
 cat > sub/Tupfile << HERE
 : |> if [ -f ghost/foo ]; then cat ghost/foo; else echo nofile; fi > %o |> output.txt
 HERE
-tup touch build/tup.config sub/Tupfile
 update
 
 echo nofile | diff - build/sub/output.txt
 
-tmkdir sub/ghost
+mkdir sub/ghost
 echo hey > sub/ghost/foo
 update
 
