@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -18,16 +18,15 @@
 
 # Make sure we can go from a variant to in-tree build with a tup.config
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build
-tmkdir sub
+mkdir build
+mkdir sub
 
 cat > Tupfile << HERE
 .gitignore
 : foreach *.c |> gcc -c %f -o %o |> %B.o
 ifeq (@(FOO),y)
-: *.o sub/*.o |> gcc %f -o %o |> prog
+: *.o sub/*.o |> gcc %f -o %o |> prog.exe
 endif
 HERE
 cat > sub/Tupfile << HERE
@@ -36,21 +35,21 @@ cat > sub/Tupfile << HERE
 HERE
 echo "int main(void) {return 0;}" > foo.c
 echo 'CONFIG_FOO=y' > build/tup.config
-tup touch Tupfile foo.c sub/bar.c build/tup.config
+touch sub/bar.c
 update
 
-check_exist build/foo.o build/sub/bar.o build/prog
-check_not_exist foo.o sub/bar.o prog
+check_exist build/foo.o build/sub/bar.o build/prog.exe
+check_not_exist foo.o sub/bar.o prog.exe
 
 mv build/tup.config .
 update
 
-check_not_exist build/foo.o build/sub/bar.o build/prog build/sub
-check_exist foo.o sub/bar.o prog
+check_not_exist build/foo.o build/sub/bar.o build/prog.exe build/sub
+check_exist foo.o sub/bar.o prog.exe
 
 rm tup.config
 update
 
-check_not_exist prog
+check_not_exist prog.exe
 
 eotup
