@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -18,9 +18,8 @@
 
 # Go from in-tree to variant to in-tree to variant.
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build
+mkdir build
 
 cat > Tupfile << HERE
 .gitignore
@@ -29,7 +28,6 @@ ifeq (@(DEBUG),y)
 endif
 : |> touch %o |> bar
 HERE
-tup touch Tupfile
 update
 
 touch build/tup.config
