@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -20,9 +20,9 @@
 # by creating a very long command string, so that if we do try to unlink
 # it, it will fail with a name too long error.
 . ./tup.sh
-check_no_windows variant
+check_no_windows shell
 
-tmkdir build
+mkdir build
 
 for i in `seq 1 100`; do
 	text="$text $i"
@@ -32,7 +32,7 @@ cat > Tupfile << HERE
 .gitignore
 : |> ^ echo^ echo $text > /dev/null |>
 HERE
-tup touch Tupfile build/tup.config
+touch build/tup.config
 update
 
 rm build/tup.config
