@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,9 +19,8 @@
 # Go from in-tree to variant to in-tree to variant with a tup.config for
 # the in-tree build.
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build
+mkdir build
 
 cat > Tupfile << HERE
 .gitignore
@@ -31,7 +30,6 @@ endif
 : |> touch %o |> bar
 HERE
 echo 'CONFIG_DEBUG=y' > tup.config
-tup touch Tupfile tup.config
 update
 
 check_exist foo bar
