@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -21,9 +21,8 @@
 # since the generated file is going in a different directory than where the
 # normal files are.
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build-default
+mkdir build-default
 
 cat > Tupfile << HERE
 ifeq (@(DEBUG),y)
@@ -32,7 +31,7 @@ endif
 : |> touch %o |> bar
 HERE
 echo "" > build-default/tup.config
-tup touch bar Tupfile
+touch bar
 
 update_fail_msg "Attempting to insert 'bar' as a generated node.*in the source directory"
 
