@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -18,31 +18,30 @@
 
 # Try to create an extra tup.config in the root directory after a variant.
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build
-tmkdir sub
+mkdir build
+mkdir sub
 
 cat > Tupfile << HERE
 .gitignore
 : foreach *.c |> gcc -c %f -o %o |> %B.o
-: *.o sub/*.o |> gcc %f -o %o |> prog
+: *.o sub/*.o |> gcc %f -o %o |> prog.exe
 HERE
 cat > sub/Tupfile << HERE
 .gitignore
 : foreach bar.c |> gcc -c %f -o %o |> %B.o
 HERE
 echo "int main(void) {return 0;}" > foo.c
-tup touch Tupfile foo.c build/tup.config sub/bar.c
+touch build/tup.config sub/bar.c
 update
 
-check_exist build/foo.o build/sub/bar.o build/prog build/.gitignore build/sub/.gitignore
-check_not_exist foo.o sub/bar.o prog
+check_exist build/foo.o build/sub/bar.o build/prog.exe build/.gitignore build/sub/.gitignore
+check_not_exist foo.o sub/bar.o prog.exe
 
-tup touch tup.config
+touch tup.config
 update
 
-check_exist build/foo.o build/sub/bar.o build/prog build/.gitignore build/sub/.gitignore
-check_not_exist foo.o sub/bar.o prog
+check_exist build/foo.o build/sub/bar.o build/prog.exe build/.gitignore build/sub/.gitignore
+check_not_exist foo.o sub/bar.o prog.exe
 
 eotup
