@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,18 +19,17 @@
 # Make sure the build dir for a new variant is not propagated to other
 # variants.
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build1
-tmkdir build2
+mkdir build1
+mkdir build2
 
-tup touch build1/tup.config
+touch build1/tup.config
 update
 
 check_exist build1/build2
 check_not_exist build2/build1
 
-tup touch build2/tup.config
+touch build2/tup.config
 update
 
 check_not_exist build1/build2
