@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,11 +19,10 @@
 # Make sure we can only create a variant in an empty directory (except for
 # tup.config)
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build
+mkdir build
 
-tup touch build/tup.config build/Tupfile build/foo.c
+touch build/tup.config build/Tupfile build/foo.c
 update_fail_msg "Variant directory must only contain a tup.config file"
 
 eotup
