@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -18,15 +18,14 @@
 
 # Try to move the tup.config to a srcdir accidentally.
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build
-tmkdir sub
+mkdir build
+mkdir sub
 
 cat > sub/Tupfile << HERE
 : foreach *.c |> gcc -c %f -o %o |> %B.o
 HERE
-tup touch build/tup.config sub/foo.c sub/bar.c
+touch build/tup.config sub/foo.c sub/bar.c
 update
 
 check_exist build/sub/foo.o build/sub/bar.o
