@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,11 +19,11 @@
 # Use the 'tup variant' command on config files further down in the
 # directory structure.
 . ./tup.sh
-check_no_windows variant
+check_no_windows tup variant
 
-tmkdir sub
-tmkdir sub/foo
-tmkdir sub/foo/configs
+mkdir sub
+mkdir sub/foo
+mkdir sub/foo/configs
 
 cat > Tupfile << HERE
 ifeq (@(DEBUG),y)
@@ -36,7 +36,6 @@ echo "" > sub/foo/configs/default
 cd sub/foo
 tup variant configs/*
 cd ../..
-tup touch Tupfile
 update
 
 check_exist build-default/bar
@@ -49,7 +48,6 @@ tup_object_no_exist build-default build-debug
 tup_object_no_exist build-debug build-default
 
 echo "" > sub/foo/configs/debug
-tup touch sub/foo/configs/debug
 update
 
 check_exist build-default/bar
