@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -18,17 +18,17 @@
 
 # Try to rm -rf multiple variants.
 . ./tup.sh
-check_no_windows variant
+check_no_windows tup variant
 
-tmkdir sub
-tmkdir configs
-tmkdir build-default
-tmkdir build-debug
+mkdir sub
+mkdir configs
+mkdir build-default
+mkdir build-debug
 
 cat > sub/Tupfile << HERE
 : foreach *.c |> gcc -c %f -o %o |> %B.o
 HERE
-tup touch build-default/tup.config build-debug/tup.config sub/Tupfile sub/foo.c sub/bar.c
+touch build-default/tup.config build-debug/tup.config sub/foo.c sub/bar.c
 
 update
 
