@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,25 +19,23 @@
 # Make sure we get a sane error message if we try to explicitly list a file
 # in a ghost directory.
 . ./tup.sh
-check_no_windows variant
+check_no_windows shell
 
-tmkdir build
-tmkdir sub
+mkdir build
+mkdir sub
 
 cat > Tupfile << HERE
 : |> if [ -f ghost-dir/foo ]; then cat ghost-dir/foo; else echo nofile; fi > %o |> output.txt
 HERE
 echo "CONFIG_FOO=y" > build/tup.config
-tup touch build/tup.config Tupfile
 update
 
 echo 'nofile' | diff - build/output.txt
 tup_object_exist . ghost-dir
-tup_object_exist build ghost-dir
 
 cat > sub/Tupfile << HERE
 : ../ghost-dir/bar |> cat %f |>
 HERE
-parse_fail_msg "Explicitly named file 'bar' not found"
+parse_fail_msg "Failed to find directory ID for dir '../ghost-dir/bar' relative to '\[build\] sub'"
 
 eotup
