@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -20,10 +20,9 @@
 # variant has the junk in it from the old variant. Once we delete that out,
 # it should get rebuilt.
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build-foo
-tmkdir sub
+mkdir build-foo
+mkdir sub
 
 cat > sub/Tupfile << HERE
 : foreach *.c |> gcc -c %f -o %o |> %B.o
