@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,16 +19,15 @@
 # Test that a node-variable cannot refer to a generated file in a variant build.
 
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build
+mkdir build
 
 cat > Tupfile << HERE
 : |> touch %o |> a.txt
 &node_var = a.txt
 HERE
 
-tup touch Tupfile build/tup.config
-update_fail_msg "Node-variables can only refer to normal files and directories, not a 'generated file'."
+touch build/tup.config
+update_fail_msg "Unable to find tup entry for file 'a.txt' in node reference declaration."
 
 eotup
