@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -21,11 +21,10 @@
 # (t2123 + variants)
 
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build
-tmkdir sw
-tmkdir lib
+mkdir build
+mkdir sw
+mkdir lib
 
 cat > Tuprules.tup << HERE
 &lib_tupfile = lib/lib.tup
@@ -45,9 +44,9 @@ include &(lib_tupfile)
 : foreach \$(static_libs) |> cp %f %o |> %b.copy
 HERE
 
-tup touch Tuprules.tup lib/lib.tup lib/foo.a lib/Tupfile sw/Tupfile build/tup.config
+touch lib/foo.a build/tup.config
 update
 
-tup_dep_exist build/lib lib.a build/sw 'cp ../lib/lib.a lib.a.copy'
+tup_dep_exist build/lib lib.a build/sw 'cp ../build/lib/lib.a ../build/sw/lib.a.copy'
 
 eotup
