@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,7 +19,8 @@
 # Make sure replacing a directory with a symlink works with variants.
 
 . ./tup.sh
-check_no_windows variant
+check_no_windows symlink
+check_no_ldpreload symlink-dir
 
 mkdir foo
 touch foo/foo.h
@@ -45,8 +46,7 @@ HERE
 update
 
 check_exist build/dist/bar/sub
-tup_dep_exist dist/bar/sub foo.h build 'gcc -c foo.c -o foo.o -Idist'
-sleep 1
+tup_dep_exist dist/bar/sub foo.h build 'gcc -c foo.c -o build/foo.o -Idist'
 
 rm -rf dist/bar/sub
 cd dist/bar
@@ -55,6 +55,6 @@ cd ../..
 update
 
 check_not_exist build/dist/bar/sub
-tup_dep_exist dist/bar sub build 'gcc -c foo.c -o foo.o -Idist'
+tup_dep_exist dist/bar sub build 'gcc -c foo.c -o build/foo.o -Idist'
 
 eotup
