@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,7 +19,6 @@
 # Same as t6053, but in a variant.
 
 . ./tup.sh
-check_no_windows variant
 
 mkdir build
 touch build/tup.config
@@ -28,7 +27,6 @@ cat > Tupfile << HERE
 : |> echo generated > %o |> genfile.txt
 : genfile.txt |> cat %f > %o |> output.txt
 HERE
-tup touch Tupfile
 update
 
 echo 'generated' | diff - build/output.txt
@@ -37,7 +35,6 @@ cat > Tupfile << HERE
 : genfile.txt |> cat %f > %o |> output.txt
 HERE
 echo 'manual' > genfile.txt
-tup touch genfile.txt Tupfile
 update
 
 echo 'manual' | diff - build/output.txt
