@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -21,7 +21,6 @@
 # root directory.
 
 . ./tup.sh
-check_no_windows variant
 
 mkdir build
 touch build/tup.config
@@ -30,14 +29,12 @@ cat > Tupfile << HERE
 : |> echo generated > %o |> genfile.txt
 : genfile.txt |> cat %f > %o |> output.txt
 HERE
-tup touch Tupfile
 parse
 
 cat > Tupfile << HERE
 : genfile.txt |> cat %f > %o |> output.txt
 HERE
 echo 'manual' > genfile.txt
-tup touch genfile.txt Tupfile
 update
 
 echo 'manual' | diff - build/output.txt
