@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -18,12 +18,12 @@
 
 # Use a variant with a generated directory.
 . ./tup.sh
-check_no_windows variant
+check_no_windows tup variant
 
 touch tup.config
-tmkdir a
-tmkdir a/b
-tmkdir a/b/c
+mkdir a
+mkdir a/b
+mkdir a/b/c
 
 cat > a/b/c/Tupfile << HERE
 : |> ^ Running test^ echo test > %o |> results/extra.txt
@@ -34,7 +34,6 @@ update
 cat > a/b/c/Tupfile << HERE
 : |> false |>
 HERE
-tup touch a/b/c/Tupfile
 update_fail_msg 'failed with return value 1'
 
 check_not_exist build-tup/a/b/c/results/extra.txt
@@ -43,7 +42,6 @@ check_not_exist build-tup/a/b/c/results
 cat > a/b/c/Tupfile << HERE
 : |> ^ Running test^ echo test > %o |> results/extra.txt
 HERE
-tup touch a/b/c/Tupfile
 update
 
 check_exist build-tup/a/b/c/results/extra.txt
