@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2013-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2013-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -18,9 +18,8 @@
 
 # Make sure gitignore files work properly in variants.
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build
+mkdir build
 touch build/tup.config
 
 cat > Tupfile << HERE
@@ -28,7 +27,7 @@ cat > Tupfile << HERE
 : |> touch %o |> foo.txt
 HERE
 
-tmkdir bar
+mkdir bar
 cat > bar/Tupfile << HERE
 .gitignore
 : |> touch %o |> bar.txt
