@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2012-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2012-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,18 +19,18 @@
 # Try to use a _ROOT variable from TUP_CWD with a generated file.
 . ./tup.sh
 
-tmkdir build-default
+mkdir build-default
 
 cat > Tuprules.tup << HERE
 MY_ROOT = \$(TUP_CWD)
 HERE
 
-tmkdir init
+mkdir init
 cat > init/Tupfile << HERE
 : |> touch %o |> foo
 HERE
 
-tmkdir proj
+mkdir proj
 cat > proj/Tupfile << HERE
 include_rules
 : \$(MY_ROOT)/init/foo |> cat %f > %o |> out.txt
