@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2016-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2016-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,7 +19,6 @@
 # !tup_preserve has no effect without variants
 
 . ./tup.sh
-check_no_windows variant
 
 cat > Tupfile << HERE
 : file.txt |> !tup_preserve |>
@@ -43,7 +42,7 @@ cmp file.txt build-2/file.txt
 
 # Make sure we can re-parse the Tupfile now that we have file.txt in the srcdir
 # and the build dir.
-tup touch Tupfile
+touch Tupfile
 update > .tup/.tupoutput
 if grep 'preserve file.txt' .tup/.tupoutput > /dev/null; then
 	cat .tup/.tupoutput
