@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2020-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2020-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,14 +19,14 @@
 # Make sure !tup_preserve works from lua
 
 . ./tup.sh
-check_no_windows variant
+check_bash
 
 cat > Tupfile.lua << HERE
 tup.rule({'file.txt'}, '!tup_preserve')
 tup.rule('file.txt', 'bash gen.sh %f %o', 'out.txt')
 HERE
-tmkdir sub
-tmkdir sub/bar
+mkdir sub
+mkdir sub/bar
 cp Tupfile.lua sub/bar/Tupfile.lua
 cat > gen.sh << HERE
 (echo -n "generated "; cat \$1) > \$2
@@ -54,7 +54,7 @@ echo 'generated subdir content' | diff - build/sub/bar/out.txt
 
 # Make sure we can re-parse the Tupfile now that we have file.txt in the srcdir
 # and the build dir.
-tup touch Tupfile.lua sub/bar/Tupfile.lua
+touch Tupfile.lua sub/bar/Tupfile.lua
 update > .tup/.tupoutput
 if grep 'preserve file.txt' .tup/.tupoutput > /dev/null; then
 	cat .tup/.tupoutput
