@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2016-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2016-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,9 +19,8 @@
 # Make sure !tup_preserve fails if given the output of another command.
 
 . ./tup.sh
-check_no_windows variant
 
-tmkdir sub
+mkdir sub
 cat > sub/Tupfile << HERE
 : |> touch %o |> foo.txt
 HERE
@@ -35,19 +34,13 @@ cat > sub/Tupfile << HERE
 : |> touch %o |> foo.txt
 : foo.txt |> !tup_preserve |>
 HERE
-tup touch sub/Tupfile
 
-# TODO: This should probably fail with a more explicit message that
-# !tup_preserve can't use a generate file, since foo.txt is only a ghost file
-# because of how fuse accesses variants. This will probably need to be updated
-# with a better message if explicit variants are enabled.
-update_fail_msg 'Explicitly.*foo.txt.*is a ghost file'
+update_fail_msg "Explicitly named file 'foo.txt' not found in subdir 'sub'"
 
 cat > sub/Tupfile << HERE
 : |> touch %o |> foo.txt
 : bar.txt |> !tup_preserve |>
 HERE
-tup touch sub/Tupfile
 update
 
 cmp sub/bar.txt build/sub/bar.txt
