@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2015-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2015-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -18,9 +18,8 @@
 
 # Copy files from the srcdir to the variant dir.
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build
+mkdir build
 
 cat > Tupfile << HERE
 : foreach *.html |> !tup_preserve |>
@@ -28,21 +27,20 @@ cat > Tupfile << HERE
 HERE
 echo file1 > file.html
 echo file2 > file2.html
-tup touch Tupfile build/tup.config
+touch build/tup.config
 update
 
 check_exist build/file.html build/file2.html build/gen.txt
 echo file1 | diff - build/file.html
 echo file2 | diff - build/file2.html
 
-tmkdir sub
-tmkdir sub/bar
+mkdir sub
+mkdir sub/bar
 cat > sub/bar/Tupfile << HERE
 : file3.html |> !tup_preserve |>
 : |> touch %o |> gen2.txt
 HERE
 echo file3 > sub/bar/file3.html
-tup touch sub/bar/Tupfile
 update
 
 check_exist build/sub/bar/file3.html build/sub/bar/gen2.txt
