@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2015-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2015-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -18,15 +18,14 @@
 
 # Make sure removing the source file means the variant copy is deleted.
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build
+mkdir build
 
 cat > Tupfile << HERE
 : foreach *.html |> !tup_preserve |>
 : |> touch %o |> gen.txt
 HERE
-tup touch Tupfile file.html file2.html build/tup.config
+touch file.html file2.html build/tup.config
 update
 
 check_exist build/file.html build/file2.html build/gen.txt
