@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2015-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2015-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -18,26 +18,25 @@
 
 # Use !tup_preserve without any variants.
 . ./tup.sh
-check_no_windows variant
 
-tmkdir build
+mkdir build
 
 cat > Tupfile << HERE
 : foreach *.html |> !tup_preserve |>
 : |> touch %o |> gen.txt
 HERE
-tup touch Tupfile file.html file2.html
+touch file.html file2.html
 update
 
 check_exist file.html file2.html gen.txt
 
-tmkdir sub
-tmkdir sub/bar
+mkdir sub
+mkdir sub/bar
 cat > sub/bar/Tupfile << HERE
 : file2.html |> !tup_preserve |>
 : |> touch %o |> gen2.txt
 HERE
-tup touch sub/bar/Tupfile sub/bar/file2.html
+touch sub/bar/file2.html
 update
 
 check_exist sub/bar/file2.html sub/bar/gen2.txt
