@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2016-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2016-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,19 +19,19 @@
 # Same as t2196, but in a variant.
 
 . ./tup.sh
-check_no_windows variant
+check_no_windows paths
 
-tmkdir sub
+mkdir sub
 cat > sub/Tupfile << HERE
 : `pwd -P`/foo/input.txt |> !tup_ln |> link.txt
 HERE
-tmkdir foo
-tup touch foo/input.txt
+mkdir foo
+touch foo/input.txt
 
-tmkdir build
-tup touch build/tup.config
+mkdir build
+touch build/tup.config
 update
 
-tup_dep_exist build/sub "!tup_ln ../../foo/input.txt link.txt" build/sub link.txt
+tup_dep_exist build/sub "!tup_ln ../foo/input.txt ../build/sub/link.txt" build/sub link.txt
 
 eotup
