@@ -1,7 +1,7 @@
 #! /bin/sh -e
 # tup - A file-based build system
 #
-# Copyright (C) 2009-2021  Mike Shal <marfey@gmail.com>
+# Copyright (C) 2009-2024  Mike Shal <marfey@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -30,7 +30,7 @@ include_rules
 HERE
 echo 'int main(void) {return 0;}' > foo.c
 
-tup touch foo.c bar.c Tupfile Tuprules.tup
+touch bar.c
 update
 
 gitignore_good '/\\\[asd\\\].exe' .gitignore
